@@ -32,7 +32,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "tabbox.h"
 #endif
 #include "screenedge.h"
-#include "tabgroup.h"
 #include "useractions.h"
 #include "workspace.h"
 
@@ -89,7 +88,7 @@ AbstractClient::AbstractClient()
             Q_UNUSED(c)
             if (isOnScreenDisplay() && !geometry().isEmpty() && old.size() != geometry().size() && !isInitialPositionSet()) {
                 GeometryUpdatesBlocker blocker(this);
-                QRect area = workspace()->clientArea(PlacementArea, Screens::self()->current(), desktop());
+                const QRect area = workspace()->clientArea(PlacementArea, Screens::self()->current(), desktop());
                 Placement::self()->place(this, area);
                 setGeometryRestore(geometry());
             }
@@ -107,7 +106,7 @@ AbstractClient::AbstractClient()
 
 AbstractClient::~AbstractClient()
 {
-    assert(m_blockGeometryUpdates == 0);
+    Q_ASSERT(m_blockGeometryUpdates == 0);
     Q_ASSERT(m_decoration.decoration == nullptr);
 }
 
@@ -125,96 +124,11 @@ bool AbstractClient::isTransient() const
     return false;
 }
 
-void AbstractClient::setTabGroup(TabGroup* group)
-{
-    tab_group = group;
-    emit tabGroupChanged();
-}
-
 void AbstractClient::setClientShown(bool shown)
 {
     Q_UNUSED(shown)
 }
 
-bool AbstractClient::untab(const QRect &toGeometry, bool clientRemoved)
-{
-    TabGroup *group = tab_group;
-    if (group && group->remove(this)) { // remove sets the tabgroup to "0", therefore the pointer is cached
-        if (group->isEmpty()) {
-            delete group;
-        }
-        if (clientRemoved)
-            return true; // there's been a broadcast signal that this client is now removed - don't touch it
-        setClientShown(!(isMinimized() || isShade()));
-        bool keepSize = toGeometry.size() == size();
-        bool changedSize = false;
-        if (quickTileMode() != QuickTileMode(QuickTileFlag::None)) {
-            changedSize = true;
-            setQuickTileMode(QuickTileFlag::None); // if we leave a quicktiled group, assume that the user wants to untile
-        }
-        if (toGeometry.isValid()) {
-            if (maximizeMode() != MaximizeRestore) {
-                changedSize = true;
-                maximize(MaximizeRestore); // explicitly calling for a geometry -> unmaximize
-            }
-            if (keepSize && changedSize) {
-                setGeometryRestore(geometry()); // checkWorkspacePosition() invokes it
-                QPoint cpoint = Cursor::pos();
-                QPoint point = cpoint;
-                point.setX((point.x() - toGeometry.x()) * geometryRestore().width() / toGeometry.width());
-                point.setY((point.y() - toGeometry.y()) * geometryRestore().height() / toGeometry.height());
-                auto geometry_restore = geometryRestore();
-                geometry_restore.moveTo(cpoint-point);
-                setGeometryRestore(geometry_restore);
-            } else {
-                setGeometryRestore(toGeometry); // checkWorkspacePosition() invokes it
-            }
-            setGeometry(geometryRestore());
-            checkWorkspacePosition();
-        }
-        return true;
-    }
-    return false;
-}
-
-bool AbstractClient::tabTo(AbstractClient *other, bool behind, bool activate)
-{
-    Q_ASSERT(other && other != this);
-
-    if (tab_group && tab_group == other->tabGroup()) { // special case: move inside group
-        tab_group->move(this, other, behind);
-        return true;
-    }
-
-    GeometryUpdatesBlocker blocker(this);
-    const bool wasBlocking = signalsBlocked();
-    blockSignals(true); // prevent client emitting "retabbed to nowhere" cause it's about to be entabbed the next moment
-    untab();
-    blockSignals(wasBlocking);
-
-    TabGroup *newGroup = other->tabGroup() ? other->tabGroup() : new TabGroup(other);
-
-    if (!newGroup->add(this, other, behind, activate)) {
-        if (newGroup->count() < 2) { // adding "c" to "to" failed for whatever reason
-            newGroup->remove(other);
-            delete newGroup;
-        }
-        return false;
-    }
-    return true;
-}
-
-void AbstractClient::syncTabGroupFor(QString property, bool fromThisClient)
-{
-    if (tab_group)
-        tab_group->sync(property.toAscii().data(), fromThisClient ? this : tab_group->current());
-}
-
-bool AbstractClient::isCurrentTab() const
-{
-    return !tab_group || tab_group->current() == this;
-}
-
 MaximizeMode AbstractClient::requestedMaximizeMode() const
 {
     return maximizeMode();
@@ -353,6 +267,8 @@ Layer AbstractClient::belongsToLayer() const
     // and the docks move into the NotificationLayer (which is between Above- and
     // ActiveLayer, so that active fullscreen windows will still cover everything)
     // Since the desktop is also activated, nothing should be in the ActiveLayer, though
+    if (isInternal())
+        return UnmanagedLayer;
     if (isDesktop())
         return workspace()->showingDesktop() ? AboveLayer : DesktopLayer;
     if (isSplash())          // no damn annoying splashscreens
@@ -406,12 +322,12 @@ void AbstractClient::setKeepAbove(bool b)
     if (b == keepAbove()) {
         // force hint change if different
         if (info && bool(info->state() & NET::KeepAbove) != keepAbove())
-            info->setState(keepAbove() ? NET::KeepAbove : NET::States(0), NET::KeepAbove);
+            info->setState(keepAbove() ? NET::KeepAbove : NET::States(), NET::KeepAbove);
         return;
     }
     m_keepAbove = b;
     if (info) {
-        info->setState(keepAbove() ? NET::KeepAbove : NET::States(0), NET::KeepAbove);
+        info->setState(keepAbove() ? NET::KeepAbove : NET::States(), NET::KeepAbove);
     }
     workspace()->updateClientLayer(this);
     updateWindowRules(Rules::Above);
@@ -432,12 +348,12 @@ void AbstractClient::setKeepBelow(bool b)
     if (b == keepBelow()) {
         // force hint change if different
         if (info && bool(info->state() & NET::KeepBelow) != keepBelow())
-            info->setState(keepBelow() ? NET::KeepBelow : NET::States(0), NET::KeepBelow);
+            info->setState(keepBelow() ? NET::KeepBelow : NET::States(), NET::KeepBelow);
         return;
     }
     m_keepBelow = b;
     if (info) {
-        info->setState(keepBelow() ? NET::KeepBelow : NET::States(0), NET::KeepBelow);
+        info->setState(keepBelow() ? NET::KeepBelow : NET::States(), NET::KeepBelow);
     }
     workspace()->updateClientLayer(this);
     updateWindowRules(Rules::Below);
@@ -490,7 +406,7 @@ void AbstractClient::demandAttention(bool set)
         return;
     m_demandsAttention = set;
     if (info) {
-        info->setState(set ? NET::DemandsAttention : NET::States(0), NET::DemandsAttention);
+        info->setState(set ? NET::DemandsAttention : NET::States(), NET::DemandsAttention);
     }
     workspace()->clientAttentionChanged(this, set);
     emit demandsAttentionChanged();
@@ -698,7 +614,7 @@ void AbstractClient::minimize(bool avoid_animation)
         return;
 
     if (isShade() && info) // NETWM restriction - KWindowInfo::isMinimized() == Hidden && !Shaded
-        info->setState(0, NET::Shaded);
+        info->setState(NET::States(), NET::Shaded);
 
     m_minimized = true;
 
@@ -887,7 +803,7 @@ void AbstractClient::setupWindowManagementInterface()
     w->setMovable(isMovable());
     w->setVirtualDesktopChangeable(true); // FIXME Matches Client::actionSupported(), but both should be implemented.
     w->setParentWindow(transientFor() ? transientFor()->windowManagementInterface() : nullptr);
-    w->setGeometry(geom);
+    w->setGeometry(geometry());
     connect(this, &AbstractClient::skipTaskbarChanged, w,
         [w, this] {
             w->setSkipTaskbar(skipTaskbar());
@@ -927,7 +843,7 @@ void AbstractClient::setupWindowManagementInterface()
     );
     connect(this, &AbstractClient::geometryChanged, w,
         [w, this] {
-            w->setGeometry(geom);
+            w->setGeometry(geometry());
         }
     );
     connect(w, &PlasmaWindowInterface::closeRequested, this, [this] { closeWindow(); });
@@ -1193,14 +1109,6 @@ bool AbstractClient::performMouseCommand(Options::MouseCommand cmd, const QPoint
         if (!isDesktop())   // No point in changing the opacity of the desktop
             setOpacity(qMax(opacity() - 0.1, 0.1));
         break;
-    case Options::MousePreviousTab:
-        if (tabGroup())
-            tabGroup()->activatePrev();
-    break;
-    case Options::MouseNextTab:
-        if (tabGroup())
-            tabGroup()->activateNext();
-    break;
     case Options::MouseClose:
         closeWindow();
         break;
@@ -1256,7 +1164,6 @@ bool AbstractClient::performMouseCommand(Options::MouseCommand cmd, const QPoint
         updateCursor();
         break;
     }
-    case Options::MouseDragTab:
     case Options::MouseNothing:
     default:
         replay = true;
@@ -1341,8 +1248,8 @@ bool AbstractClient::isModal() const
 
 void AbstractClient::addTransient(AbstractClient *cl)
 {
-    assert(!m_transients.contains(cl));
-    assert(cl != this);
+    Q_ASSERT(!m_transients.contains(cl));
+    Q_ASSERT(cl != this);
     m_transients.append(cl);
 }
 
@@ -1400,11 +1307,7 @@ void AbstractClient::addRepaintDuringGeometryUpdates()
 
 void AbstractClient::updateGeometryBeforeUpdateBlocking()
 {
-    m_geometryBeforeUpdateBlocking = geom;
-}
-
-void AbstractClient::updateTabGroupStates(TabGroup::States)
-{
+    m_geometryBeforeUpdateBlocking = geometry();
 }
 
 void AbstractClient::doMove(int, int)
@@ -1740,8 +1643,8 @@ bool AbstractClient::processDecorationButtonPress(QMouseEvent *event, bool ignor
         com = active ? options->commandActiveTitlebar3() : options->commandInactiveTitlebar3();
     if (event->button() == Qt::LeftButton
             && com != Options::MouseOperationsMenu // actions where it's not possible to get the matching
-            && com != Options::MouseMinimize  // mouse release event
-            && com != Options::MouseDragTab) {
+            && com != Options::MouseMinimize)  // mouse release event
+    {
         setMoveResizePointerMode(mousePosition());
         setMoveResizePointerButtonDown(true);
         setMoveOffset(event->pos());
@@ -1761,7 +1664,6 @@ bool AbstractClient::processDecorationButtonPress(QMouseEvent *event, bool ignor
                com == Options::MouseActivate ||
                com == Options::MouseActivateRaiseAndPassClick ||
                com == Options::MouseActivateAndPassClick ||
-               com == Options::MouseDragTab ||
                com == Options::MouseNothing);
 }
 
@@ -2080,4 +1982,14 @@ Group *AbstractClient::group()
     return nullptr;
 }
 
+bool AbstractClient::isInternal() const
+{
+    return false;
+}
+
+bool AbstractClient::supportsWindowRules() const
+{
+    return true;
+}
+
 }
