@@ -35,7 +35,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "activities.h"
 #endif
 
-#include <fixx11h.h>
 #include <kstartupinfo.h>
 #include <kstringhandler.h>
 #include <KLocalizedString>
@@ -226,7 +225,7 @@ namespace KWin
  * effect than fixing the focus chain and the return value of
  * activeClient(). And of course, to propagate the active client to the
  * world.
- **/
+ */
 void Workspace::setActiveClient(AbstractClient* c)
 {
     if (active_client == c)
@@ -289,7 +288,7 @@ void Workspace::setActiveClient(AbstractClient* c)
  *
  * @see setActiveClient
  * @see requestFocus
- **/
+ */
 void Workspace::activateClient(AbstractClient* c, bool force)
 {
     if (c == NULL) {
@@ -340,7 +339,7 @@ void Workspace::activateClient(AbstractClient* c, bool force)
  * Workspace::activateClient() instead.
  *
  * @see activateClient
- **/
+ */
 void Workspace::requestFocus(AbstractClient* c, bool force)
 {
     takeActivity(c, force ? ActivityFocusForce : ActivityFocus);
@@ -389,8 +388,6 @@ void Workspace::takeActivity(AbstractClient* c, ActivityFlags flags)
         }
         flags &= ~ActivityFocus;
     }
-    if (c->tabGroup() && c->tabGroup()->current() != c)
-        c->tabGroup()->setCurrent(c);
     if (!c->isShown(true)) {  // shouldn't happen, call activateClient() if needed
         qCWarning(KWIN_CORE) << "takeActivity: not shown" ;
         return;
@@ -411,10 +408,10 @@ void Workspace::takeActivity(AbstractClient* c, ActivityFlags flags)
  * the workspace activates another one.
  *
  * @note @p c may already be destroyed.
- **/
+ */
 void Workspace::clientHidden(AbstractClient* c)
 {
-    assert(!c->isShown(true) || !c->isOnCurrentDesktop() || !c->isOnCurrentActivity());
+    Q_ASSERT(!c->isShown(true) || !c->isOnCurrentDesktop() || !c->isOnCurrentActivity());
     activateNextClient(c);
 }
 
@@ -467,15 +464,6 @@ bool Workspace::activateNextClient(AbstractClient* c)
 
     AbstractClient* get_focus = NULL;
 
-    // precedence on keeping the current tabgroup active. to the user that's the same window
-    if (c && c->tabGroup() && c->isShown(false)) {
-        if (c == c->tabGroup()->current())
-            c->tabGroup()->activateNext();
-        get_focus = c->tabGroup()->current();
-        if (get_focus == c) // single tab case - should not happen
-            get_focus = NULL;
-    }
-
     const int desktop = VirtualDesktopManager::self()->current();
 
     if (!get_focus && showingDesktop())
@@ -634,7 +622,7 @@ bool Workspace::allowClientActivation(const KWin::AbstractClient *c, xcb_timesta
     }
 
     // Low or medium FSP, usertime comparism is possible
-    Time user_time = ac->userTime();
+    const xcb_timestamp_t user_time = ac->userTime();
     qCDebug(KWIN_CORE) << "Activation, compared:" << c << ":" << time << ":" << user_time
                  << ":" << (NET::timestampCompare(time, user_time) >= 0);
     return NET::timestampCompare(time, user_time) >= 0;   // time >= user_time
@@ -706,7 +694,7 @@ void Workspace::clientAttentionChanged(AbstractClient* c, bool set)
  * This is called inside  kwin for every action with the window
  * that qualifies for user interaction (clicking on it, activate it
  * externally, etc.).
- **/
+ */
 void Client::updateUserTime(xcb_timestamp_t time)
 {
     // copied in Group::updateUserTime
@@ -813,7 +801,7 @@ xcb_timestamp_t Client::userTime() const
     xcb_timestamp_t time = m_userTime;
     if (time == 0)   // doesn't want focus after showing
         return 0;
-    assert(group() != NULL);
+    Q_ASSERT(group() != NULL);
     if (time == -1U
             || (group()->userTime() != -1U
                 && NET::timestampCompare(group()->userTime(), time) > 0))
@@ -844,7 +832,7 @@ void Client::startupIdChanged()
         workspace()->sendClientToDesktop(this, desktop, true);
     if (asn_data.xinerama() != -1)
         workspace()->sendClientToScreen(this, asn_data.xinerama());
-    Time timestamp = asn_id.timestamp();
+    const xcb_timestamp_t timestamp = asn_id.timestamp();
     if (timestamp != 0) {
         bool activate = workspace()->allowClientActivation(this, timestamp);
         if (asn_data.desktop() != 0 && !isOnCurrentDesktop())
