@@ -93,7 +93,7 @@ class HelperEffect : public Effect
     Q_OBJECT
 public:
     HelperEffect() {}
-    ~HelperEffect() {}
+    ~HelperEffect() override {}
 
     void windowInputMouseEvent(QEvent*) override {
         emit inputEvent();
@@ -189,8 +189,8 @@ void LockScreenTest::initTestCase()
     QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
     QVERIFY(workspaceCreatedSpy.isValid());
     kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
-    QMetaObject::invokeMethod(kwinApp()->platform(), "setVirtualOutputs", Qt::DirectConnection, Q_ARG(int, 2));
     QVERIFY(waylandServer()->init(s_socketName.toLocal8Bit()));
+    QMetaObject::invokeMethod(kwinApp()->platform(), "setVirtualOutputs", Qt::DirectConnection, Q_ARG(int, 2));
 
     qputenv("KWIN_COMPOSE", QByteArrayLiteral("O2"));
     kwinApp()->start();
