@@ -53,13 +53,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QFileInfo>
 #include <QMouseEvent>
 #include <QProcess>
-// XLib
-#include <X11/Xutil.h>
-#include <fixx11h.h>
+// xcb
 #include <xcb/xcb_icccm.h>
 // system
 #include <unistd.h>
-#include <signal.h>
+// c++
+#include <csignal>
 
 // Put all externs before the namespace statement to allow the linker
 // to resolve them properly
@@ -89,12 +88,12 @@ const long ClientWinMask = XCB_EVENT_MASK_KEY_PRESS | XCB_EVENT_MASK_KEY_RELEASE
 /**
  * \class Client client.h
  * \brief The Client class encapsulates a window decoration frame.
- **/
+ */
 
 /**
  * This ctor is "dumb" - it only initializes data. All the real initialization
  * is done in manage().
- **/
+ */
 Client::Client()
     : AbstractClient()
     , m_client()
@@ -140,7 +139,7 @@ Client::Client()
 
     shade_mode = ShadeNone;
     deleting = false;
-    fullscreen_mode = FullScreenNone;
+    m_fullscreenMode = FullScreenNone;
     hidden = false;
     noborder = false;
     app_noborder = false;
@@ -171,37 +170,25 @@ Client::Client()
         }
     });
 
-    connect(this, &Client::tabGroupChanged, this,
-        [this] {
-            auto group = tabGroup();
-            if (group) {
-                unsigned long data[] = {qHash(group)}; //->id();
-                m_client.changeProperty(atoms->kde_net_wm_tab_group, XCB_ATOM_CARDINAL, 32, 1, data);
-            }
-            else
-                m_client.deleteProperty(atoms->kde_net_wm_tab_group);
-        });
-
     // SELI TODO: Initialize xsizehints??
 }
 
 /**
  * "Dumb" destructor.
- **/
+ */
 Client::~Client()
 {
     if (m_killHelperPID && !::kill(m_killHelperPID, 0)) { // means the process is alive
         ::kill(m_killHelperPID, SIGTERM);
         m_killHelperPID = 0;
     }
-    //SWrapper::Client::clientRelease(this);
     if (syncRequest.alarm != XCB_NONE)
         xcb_sync_destroy_alarm(connection(), syncRequest.alarm);
-    assert(!isMoveResize());
-    assert(m_client == XCB_WINDOW_NONE);
-    assert(m_wrapper == XCB_WINDOW_NONE);
-    //assert( frameId() == None );
-    assert(!check_active_modal);
+    Q_ASSERT(!isMoveResize());
+    Q_ASSERT(m_client == XCB_WINDOW_NONE);
+    Q_ASSERT(m_wrapper == XCB_WINDOW_NONE);
+    Q_ASSERT(m_frame == XCB_WINDOW_NONE);
+    Q_ASSERT(!check_active_modal);
     for (auto it = m_connections.constBegin(); it != m_connections.constEnd(); ++it) {
         disconnect(*it);
     }
@@ -215,14 +202,14 @@ void Client::deleteClient(Client* c)
 
 /**
  * Releases the window. The client has done its job and the window is still existing.
- **/
+ */
 void Client::releaseWindow(bool on_shutdown)
 {
-    assert(!deleting);
+    Q_ASSERT(!deleting);
     deleting = true;
 #ifdef KWIN_BUILD_TABBOX
     TabBox::TabBox *tabBox = TabBox::TabBox::self();
-    if (tabBox->isDisplayed() && tabBox->currentClient() == this) {
+    if (tabBox && tabBox->isDisplayed() && tabBox->currentClient() == this) {
         tabBox->nextPrev(true);
     }
 #endif
@@ -246,7 +233,7 @@ void Client::releaseWindow(bool on_shutdown)
     // Grab X during the release to make removing of properties, setting to withdrawn state
     // and repareting to root an atomic operation (https://lists.kde.org/?l=kde-devel&m=116448102901184&w=2)
     grabXServer();
-    exportMappingState(WithdrawnState);
+    exportMappingState(XCB_ICCCM_WM_STATE_WITHDRAWN);
     setModal(false);   // Otherwise its mainwindow wouldn't get focus
     hidden = true; // So that it's not considered visible anymore (can't use hideClient(), it would set flags)
     if (!on_shutdown)
@@ -258,9 +245,8 @@ void Client::releaseWindow(bool on_shutdown)
         workspace()->removeClient(this);
         // Only when the window is being unmapped, not when closing down KWin (NETWM sections 5.5,5.7)
         info->setDesktop(0);
-        info->setState(0, info->state());  // Reset all state flags
-    } else
-        untab();
+        info->setState(NET::States(), info->state());  // Reset all state flags
+    }
     xcb_connection_t *c = connection();
     m_client.deleteProperty(atoms->kde_net_wm_user_creation_time);
     m_client.deleteProperty(atoms->net_frame_extents);
@@ -278,7 +264,6 @@ void Client::releaseWindow(bool on_shutdown)
     m_client.reset();
     m_wrapper.reset();
     m_frame.reset();
-    //frame = None;
     unblockGeometryUpdates(); // Don't use GeometryUpdatesBlocker, it would now set the geometry
     if (!on_shutdown) {
         disownDataPassedToDeleted();
@@ -291,14 +276,14 @@ void Client::releaseWindow(bool on_shutdown)
 /**
  * Like releaseWindow(), but this one is called when the window has been already destroyed
  * (E.g. The application closed it)
- **/
+ */
 void Client::destroyClient()
 {
-    assert(!deleting);
+    Q_ASSERT(!deleting);
     deleting = true;
 #ifdef KWIN_BUILD_TABBOX
     TabBox::TabBox *tabBox = TabBox::TabBox::self();
-    if (tabBox->isDisplayed() && tabBox->currentClient() == this) {
+    if (tabBox && tabBox->isDisplayed() && tabBox->currentClient() == this) {
         tabBox->nextPrev(true);
     }
 #endif
@@ -325,7 +310,6 @@ void Client::destroyClient()
     m_client.reset(); // invalidate
     m_wrapper.reset();
     m_frame.reset();
-    //frame = None;
     unblockGeometryUpdates(); // Don't use GeometryUpdatesBlocker, it would now set the geometry
     disownDataPassedToDeleted();
     del->unrefWindow();
@@ -583,7 +567,7 @@ void Client::detectGtkFrameExtents()
  * re-layouts (e.g. when maximization state changes,
  * the decoration may alter some borders, but the actual size
  * of the decoration stays the same).
- **/
+ */
 void Client::resizeDecoration()
 {
     triggerDecorationRepaint();
@@ -595,6 +579,22 @@ bool Client::userNoBorder() const
     return noborder;
 }
 
+bool Client::isFullScreenable() const
+{
+    if (!rules()->checkFullScreen(true)) {
+        return false;
+    }
+    if (rules()->checkStrictGeometry(true)) {
+        // check geometry constraints (rule to obey is set)
+        const QRect fsarea = workspace()->clientArea(FullScreenArea, this);
+        if (sizeForClientSize(fsarea.size(), SizemodeAny, true) != fsarea.size()) {
+            return false; // the app wouldn't fit exactly fullscreen geometry due to its strict geometry requirements
+        }
+    }
+    // don't check size constrains - some apps request fullscreen despite requesting fixed size
+    return !isSpecialWindow(); // also better disallow only weird types to go fullscreen
+}
+
 bool Client::noBorder() const
 {
     return userNoBorder() || isFullScreen();
@@ -602,7 +602,7 @@ bool Client::noBorder() const
 
 bool Client::userCanSetNoBorder() const
 {
-    return !isFullScreen() && !isShade() && !tabGroup();
+    return !isFullScreen() && !isShade();
 }
 
 void Client::setNoBorder(bool set)
@@ -704,9 +704,26 @@ void Client::hideClient(bool hide)
     updateVisibility();
 }
 
+bool Client::setupCompositing()
+{
+    if (!Toplevel::setupCompositing()){
+        return false;
+    }
+    updateVisibility(); // for internalKeep()
+    return true;
+}
+
+void Client::finishCompositing(ReleaseReason releaseReason)
+{
+    Toplevel::finishCompositing(releaseReason);
+    updateVisibility();
+    // for safety in case KWin is just resizing the window
+    resetHaveResizeEffect();
+}
+
 /**
  * Returns whether the window is minimizable or not
- **/
+ */
 bool Client::isMinimizable() const
 {
     if (isSpecialWindow() && !isTransient())
@@ -745,9 +762,6 @@ void Client::doMinimize()
     updateVisibility();
     updateAllowedActions();
     workspace()->updateMinimizedOfTransients(this);
-    // Update states of all other windows in this group
-    if (tabGroup())
-        tabGroup()->updateStates(this, TabGroup::Minimized);
 }
 
 QRect Client::iconGeometry() const
@@ -797,17 +811,13 @@ void Client::setShade(ShadeMode mode)
         decoration->borders(border_left, border_right, border_top, border_bottom);
 #endif
 
-    // Update states of all other windows in this group
-    if (tabGroup())
-        tabGroup()->updateStates(this, TabGroup::Shaded);
-
     if (was_shade == isShade()) {
         // Decoration may want to update after e.g. hover-shade changes
         emit shadeChanged();
         return; // No real change in shaded state
     }
 
-    assert(isDecorated());   // noborder windows can't be shaded
+    Q_ASSERT(isDecorated());   // noborder windows can't be shaded
     GeometryUpdatesBlocker blocker(this);
 
     // TODO: All this unmapping, resizing etc. feels too much duplicated from elsewhere
@@ -822,7 +832,7 @@ void Client::setShade(ShadeMode mode)
         m_wrapper.unmap();
         m_client.unmap();
         m_wrapper.selectInput(ClientWinMask | XCB_EVENT_MASK_SUBSTRUCTURE_NOTIFY);
-        exportMappingState(IconicState);
+        exportMappingState(XCB_ICCCM_WM_STATE_ICONIC);
         plainResize(s);
         shade_geometry_change = false;
         if (was_shade_mode == ShadeHover) {
@@ -861,12 +871,12 @@ void Client::setShade(ShadeMode mode)
         }
         m_wrapper.map();
         m_client.map();
-        exportMappingState(NormalState);
+        exportMappingState(XCB_ICCCM_WM_STATE_NORMAL);
         if (isActive())
             workspace()->requestFocus(this);
     }
-    info->setState(isShade() ? NET::Shaded : NET::States(0), NET::Shaded);
-    info->setState(isShown(false) ? NET::States(0) : NET::Hidden, NET::Hidden);
+    info->setState(isShade() ? NET::Shaded : NET::States(), NET::Shaded);
+    info->setState(isShown(false) ? NET::States() : NET::Hidden, NET::Hidden);
     discardWindowPixmap();
     updateVisibility();
     updateAllowedActions();
@@ -883,9 +893,7 @@ void Client::shadeHover()
 
 void Client::shadeUnhover()
 {
-    if (!tabGroup() || tabGroup()->current() == this ||
-        tabGroup()->current()->shadeMode() == ShadeNormal)
-        setShade(ShadeNormal);
+    setShade(ShadeNormal);
     cancelShadeHoverTimer();
 }
 
@@ -905,7 +913,7 @@ void Client::updateVisibility()
 {
     if (deleting)
         return;
-    if (hidden && isCurrentTab()) {
+    if (hidden) {
         info->setState(NET::Hidden, NET::Hidden);
         setSkipTaskbar(true);   // Also hide from taskbar
         if (compositing() && options->hiddenPreviews() == HiddenPreviewsAlways)
@@ -914,8 +922,7 @@ void Client::updateVisibility()
             internalHide();
         return;
     }
-    if (isCurrentTab())
-        setSkipTaskbar(originalSkipTaskbar());   // Reset from 'hidden'
+    setSkipTaskbar(originalSkipTaskbar());   // Reset from 'hidden'
     if (isMinimized()) {
         info->setState(NET::Hidden, NET::Hidden);
         if (compositing() && options->hiddenPreviews() == HiddenPreviewsAlways)
@@ -924,7 +931,7 @@ void Client::updateVisibility()
             internalHide();
         return;
     }
-    info->setState(0, NET::Hidden);
+    info->setState(NET::States(), NET::Hidden);
     if (!isOnCurrentDesktop()) {
         if (compositing() && options->hiddenPreviews() != HiddenPreviewsNever)
             internalKeep();
@@ -946,16 +953,16 @@ void Client::updateVisibility()
 /**
  * Sets the client window's mapping state. Possible values are
  * WithdrawnState, IconicState, NormalState.
- **/
+ */
 void Client::exportMappingState(int s)
 {
-    assert(m_client != XCB_WINDOW_NONE);
-    assert(!deleting || s == WithdrawnState);
-    if (s == WithdrawnState) {
+    Q_ASSERT(m_client != XCB_WINDOW_NONE);
+    Q_ASSERT(!deleting || s == XCB_ICCCM_WM_STATE_WITHDRAWN);
+    if (s == XCB_ICCCM_WM_STATE_WITHDRAWN) {
         m_client.deleteProperty(atoms->wm_state);
         return;
     }
-    assert(s == NormalState || s == IconicState);
+    Q_ASSERT(s == XCB_ICCCM_WM_STATE_NORMAL || s == XCB_ICCCM_WM_STATE_ICONIC);
 
     int32_t data[2];
     data[0] = s;
@@ -995,7 +1002,7 @@ void Client::internalHide()
 
 void Client::internalKeep()
 {
-    assert(compositing());
+    Q_ASSERT(compositing());
     if (mapping_state == Kept)
         return;
     MappingState old = mapping_state;
@@ -1014,7 +1021,7 @@ void Client::internalKeep()
  * Maps (shows) the client. Note that it is mapping state of the frame,
  * not necessarily the client window itself (i.e. a shaded window is here
  * considered mapped, even though it is in IconicState).
- **/
+ */
 void Client::map()
 {
     // XComposite invalidates backing pixmaps on unmap (minimize, different
@@ -1027,15 +1034,15 @@ void Client::map()
         m_wrapper.map();
         m_client.map();
         m_decoInputExtent.map();
-        exportMappingState(NormalState);
+        exportMappingState(XCB_ICCCM_WM_STATE_NORMAL);
     } else
-        exportMappingState(IconicState);
+        exportMappingState(XCB_ICCCM_WM_STATE_ICONIC);
     addLayerRepaint(visibleRect());
 }
 
 /**
  * Unmaps the client. Again, this is about the frame.
- **/
+ */
 void Client::unmap()
 {
     // Here it may look like a race condition, as some other client might try to unmap
@@ -1050,7 +1057,7 @@ void Client::unmap()
     m_client.unmap();
     m_decoInputExtent.unmap();
     m_wrapper.selectInput(ClientWinMask | XCB_EVENT_MASK_SUBSTRUCTURE_NOTIFY);
-    exportMappingState(IconicState);
+    exportMappingState(XCB_ICCCM_WM_STATE_ICONIC);
 }
 
 /**
@@ -1063,7 +1070,7 @@ void Client::unmap()
  * then it's hoped that there will be some other desktop above it *shrug*.
  * Using normal shape would be better, but that'd affect other things, e.g. painting
  * of the actual preview.
- **/
+ */
 void Client::updateHiddenPreview()
 {
     if (hiddenPreview()) {
@@ -1101,7 +1108,7 @@ void Client::sendClientMessage(xcb_window_t w, xcb_atom_t a, xcb_atom_t protocol
 
 /**
  * Returns whether the window may be closed (have a close button)
- **/
+ */
 bool Client::isCloseable() const
 {
     return rules()->checkCloseable(m_motif.close() && !isSpecialWindow());
@@ -1109,7 +1116,7 @@ bool Client::isCloseable() const
 
 /**
  * Closes the window by either sending a delete_window message or using XKill.
- **/
+ */
 void Client::closeWindow()
 {
     if (!isCloseable())
@@ -1129,7 +1136,7 @@ void Client::closeWindow()
 
 /**
  * Kills the window via XKill
- **/
+ */
 void Client::killWindow()
 {
     qCDebug(KWIN_CORE) << "Client::killWindow():" << caption();
@@ -1141,7 +1148,7 @@ void Client::killWindow()
 /**
  * Send a ping to the window using _NET_WM_PING if possible if it
  * doesn't respond within a reasonable time, it will be killed.
- **/
+ */
 void Client::pingWindow()
 {
     if (!info->supportsProtocol(NET::PingProtocol))
@@ -1223,17 +1230,17 @@ void Client::killProcess(bool ask, xcb_timestamp_t timestamp)
 
 void Client::doSetSkipTaskbar()
 {
-    info->setState(skipTaskbar() ? NET::SkipTaskbar : NET::States(0), NET::SkipTaskbar);
+    info->setState(skipTaskbar() ? NET::SkipTaskbar : NET::States(), NET::SkipTaskbar);
 }
 
 void Client::doSetSkipPager()
 {
-    info->setState(skipPager() ? NET::SkipPager : NET::States(0), NET::SkipPager);
+    info->setState(skipPager() ? NET::SkipPager : NET::States(), NET::SkipPager);
 }
 
 void Client::doSetSkipSwitcher()
 {
-    info->setState(skipSwitcher() ? NET::SkipSwitcher : NET::States(0), NET::SkipSwitcher);
+    info->setState(skipSwitcher() ? NET::SkipSwitcher : NET::States(), NET::SkipSwitcher);
 }
 
 void Client::doSetDesktop(int desktop, int was_desk)
@@ -1241,10 +1248,6 @@ void Client::doSetDesktop(int desktop, int was_desk)
     Q_UNUSED(desktop)
     Q_UNUSED(was_desk)
     updateVisibility();
-
-    // Update states of all other windows in this group
-    if (tabGroup())
-        tabGroup()->updateStates(this, TabGroup::Desktop);
 }
 
 /**
@@ -1253,7 +1256,7 @@ void Client::doSetDesktop(int desktop, int was_desk)
  *
  * Note: If it was on all activities and you try to remove it from one, nothing will happen;
  * I don't think that's an important enough use case to handle here.
- **/
+ */
 void Client::setOnActivity(const QString &activity, bool enable)
 {
 #ifdef KWIN_BUILD_ACTIVITIES
@@ -1279,7 +1282,7 @@ void Client::setOnActivity(const QString &activity, bool enable)
 
 /**
  * set exactly which activities this client is on
- **/
+ */
 void Client::setOnActivities(QStringList newActivitiesList)
 {
 #ifdef KWIN_BUILD_ACTIVITIES
@@ -1311,7 +1314,7 @@ void Client::setOnActivities(QStringList newActivitiesList)
         m_client.changeProperty(atoms->activities, XCB_ATOM_STRING, 8, nullUuid.length(), nullUuid.constData());
 
     } else {
-        QByteArray joined = joinedActivitiesList.toAscii();
+        QByteArray joined = joinedActivitiesList.toLatin1();
         activityList = newActivitiesList;
         m_client.changeProperty(atoms->activities, XCB_ATOM_STRING, 8, joined.length(), joined.constData());
     }
@@ -1336,7 +1339,7 @@ void Client::blockActivityUpdates(bool b)
 
 /**
  * update after activities changed
- **/
+ */
 void Client::updateActivities(bool includeTransients)
 {
     if (m_activityUpdatesBlocked) {
@@ -1348,17 +1351,13 @@ void Client::updateActivities(bool includeTransients)
     FocusChain::self()->update(this, FocusChain::MakeFirst);
     updateVisibility();
     updateWindowRules(Rules::Activity);
-
-    // Update states of all other windows in this group
-    if (tabGroup())
-        tabGroup()->updateStates(this, TabGroup::Activity);
 }
 
 /**
  * Returns the list of activities the client window is on.
  * if it's on all activities, the list will be empty.
  * Don't use this, use isOnActivity() and friends (from class Toplevel)
- **/
+ */
 QStringList Client::activities() const
 {
     if (sessionActivityOverride) {
@@ -1370,7 +1369,7 @@ QStringList Client::activities() const
 /**
  * if @p on is true, sets on all activities.
  * if it's false, sets it to only be on the current activity
- **/
+ */
 void Client::setOnAllActivities(bool on)
 {
 #ifdef KWIN_BUILD_ACTIVITIES
@@ -1389,7 +1388,7 @@ void Client::setOnAllActivities(bool on)
 
 /**
  * Performs the actual focusing of the window using XSetInputFocus and WM_TAKE_FOCUS
- **/
+ */
 void Client::takeFocus()
 {
     if (rules()->checkAcceptFocus(info->input()))
@@ -1420,7 +1419,7 @@ void Client::takeFocus()
  * contextHelp() if this is invoked.
  *
  * \sa contextHelp()
- **/
+ */
 bool Client::providesContextHelp() const
 {
     return info->supportsProtocol(NET::ContextHelpProtocol);
@@ -1431,7 +1430,7 @@ bool Client::providesContextHelp() const
  * actually provides context help.
  *
  * \sa providesContextHelp()
- **/
+ */
 void Client::showContextHelp()
 {
     if (info->supportsProtocol(NET::ContextHelpProtocol)) {
@@ -1442,7 +1441,7 @@ void Client::showContextHelp()
 /**
  * Fetches the window's caption (WM_NAME property). It will be
  * stored in the client's caption().
- **/
+ */
 void Client::fetchName()
 {
     setCaption(readName());
@@ -1567,8 +1566,6 @@ void Client::setClientShown(bool shown)
     if (shown != hidden)
         return; // nothing to change
     hidden = !shown;
-    if (options->isInactiveTabsSkipTaskbar())
-        setSkipTaskbar(hidden); // TODO: Causes reshuffle of the taskbar
     if (shown) {
         map();
         takeFocus();
@@ -1577,8 +1574,7 @@ void Client::setClientShown(bool shown)
     } else {
         unmap();
         // Don't move tabs to the end of the list when another tab get's activated
-        if (isCurrentTab())
-            FocusChain::self()->update(this, FocusChain::MakeLast);
+        FocusChain::self()->update(this, FocusChain::MakeLast);
         addWorkspaceRepaint(visibleRect());
     }
 }
@@ -1699,7 +1695,7 @@ void Client::getSyncCounter()
 
 /**
  * Send the client a _NET_SYNC_REQUEST
- **/
+ */
 void Client::sendSyncRequest()
 {
     if (syncRequest.counter == XCB_NONE || syncRequest.isPending)
@@ -2077,13 +2073,6 @@ bool Client::belongsToSameApplication(const AbstractClient *other, SameApplicati
     return Client::belongToSameApplication(this, c2, checks);
 }
 
-void Client::updateTabGroupStates(TabGroup::States states)
-{
-    if (auto t = tabGroup()) {
-        t->updateStates(this, states);
-    }
-}
-
 QSize Client::resizeIncrements() const
 {
     return m_geometryHints.resizeIncrements();
