@@ -20,7 +20,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "manager.h"
 #include "colorcorrectdbusinterface.h"
 #include "suncalc.h"
-#include "gammaramp.h"
 #include <colorcorrect_logging.h>
 
 #include <main.h>
@@ -32,9 +31,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <colorcorrect_settings.h>
 
-#include <QTimer>
+#include <KGlobalAccel>
+#include <KLocalizedString>
+
+#include <QAction>
 #include <QDBusConnection>
 #include <QSocketNotifier>
+#include <QTimer>
 
 #ifdef Q_OS_LINUX
 #include <sys/timerfd.h>
@@ -67,8 +70,6 @@ void Manager::init()
     readConfig();
 
     if (!kwinApp()->platform()->supportsGammaControl()) {
-        // at least update the sun timings to make the values accessible via dbus
-        updateSunTimings(true);
         return;
     }
 
@@ -138,7 +139,12 @@ void Manager::init()
 void Manager::hardReset()
 {
     cancelAllTimers();
-    updateSunTimings(true);
+
+    // Timings of the Sun are not used in the constant mode.
+    if (m_mode != NightColorMode::Constant) {
+        updateSunTimings(true);
+    }
+
     if (kwinApp()->platform()->supportsGammaControl() && m_active) {
         m_running = true;
         commitGammaRamps(currentTargetTemp());
@@ -153,6 +159,53 @@ void Manager::reparseConfigAndReset()
     hardReset();
 }
 
+// FIXME: The internal OSD service doesn't work on X11 right now. Once the QPA
+// is ported away from Wayland, drop this function in favor of the internal
+// OSD service.
+static void showStatusOsd(bool enabled)
+{
+    // TODO: Maybe use different icons?
+    const QString iconName = enabled
+        ? QStringLiteral("preferences-desktop-display-nightcolor-on")
+        : QStringLiteral("preferences-desktop-display-nightcolor-off");
+
+    const QString text = enabled
+        ? i18nc("Night Color was enabled", "Night Color On")
+        : i18nc("Night Color was disabled", "Night Color Off");
+
+    QDBusMessage message = QDBusMessage::createMethodCall(
+        QStringLiteral("org.kde.plasmashell"),
+        QStringLiteral("/org/kde/osdService"),
+        QStringLiteral("org.kde.osdService"),
+        QStringLiteral("showText"));
+    message.setArguments({ iconName, text });
+
+    QDBusConnection::sessionBus().asyncCall(message);
+}
+
+void Manager::toggle()
+{
+    if (!kwinApp()->platform()->supportsGammaControl()) {
+        return;
+    }
+
+    m_active = !m_active;
+
+    showStatusOsd(m_active);
+
+    resetAllTimers();
+}
+
+void Manager::initShortcuts()
+{
+    QAction *toggleAction = new QAction(this);
+    toggleAction->setProperty("componentName", QStringLiteral(KWIN_NAME));
+    toggleAction->setObjectName(i18n("Toggle Night Color"));
+    toggleAction->setText(i18n("Toggle Night Color"));
+    KGlobalAccel::setGlobalShortcut(toggleAction, QList<QKeySequence>());
+    input()->registerShortcut(QKeySequence(), toggleAction, this, &Manager::toggle);
+}
+
 void Manager::readConfig()
 {
     Settings *s = Settings::self();
@@ -161,11 +214,17 @@ void Manager::readConfig()
     m_active = s->active();
 
     NightColorMode mode = s->mode();
-    if (mode == NightColorMode::Location || mode == NightColorMode::Timings) {
+    switch (s->mode()) {
+    case NightColorMode::Automatic:
+    case NightColorMode::Location:
+    case NightColorMode::Timings:
+    case NightColorMode::Constant:
         m_mode = mode;
-    } else {
-        // also fallback for invalid setting values
+        break;
+    default:
+        // Fallback for invalid setting values.
         m_mode = NightColorMode::Automatic;
+        break;
     }
 
     m_nightTargetTemp = qBound(MIN_TEMPERATURE, s->nightTemperature(), NEUTRAL_TEMPERATURE);
@@ -243,7 +302,10 @@ void Manager::cancelAllTimers()
 
 void Manager::resetQuickAdjustTimer()
 {
-    updateSunTimings(false);
+    // We don't use timings of the Sun in the constant mode.
+    if (m_mode != NightColorMode::Constant) {
+        updateSunTimings(false);
+    }
 
     int tempDiff = qAbs(currentTargetTemp() - m_currentTemp);
     // allow tolerance of one TEMPERATURE_STEP to compensate if a slow update is coincidental
@@ -297,6 +359,12 @@ void Manager::resetSlowUpdateStartTimer()
         return;
     }
 
+    // There is no need for starting the slow update timer. Screen color temperature
+    // will be constant all the time now.
+    if (m_mode == NightColorMode::Constant) {
+        return;
+    }
+
     // set up the next slow update
     m_slowUpdateStartTimer = new QTimer(this);
     m_slowUpdateStartTimer->setSingleShot(true);
@@ -329,9 +397,9 @@ void Manager::resetSlowUpdateTimer()
     bool isDay = daylight();
     int targetTemp = isDay ? m_dayTargetTemp : m_nightTargetTemp;
 
-    if (m_prev.first == m_prev.second) {
-        // transition time is zero
-        commitGammaRamps(isDay ? m_dayTargetTemp : m_nightTargetTemp);
+    // We've reached the target color temperature or the transition time is zero.
+    if (m_prev.first == m_prev.second || m_currentTemp == targetTemp) {
+        commitGammaRamps(targetTemp);
         return;
     }
 
@@ -486,6 +554,10 @@ int Manager::currentTargetTemp() const
         return NEUTRAL_TEMPERATURE;
     }
 
+    if (m_mode == NightColorMode::Constant) {
+       return m_nightTargetTemp;
+    }
+
     QDateTime todayNow = QDateTime::currentDateTimeUtc();
 
     auto f = [this, todayNow](int target1, int target2) {
@@ -513,20 +585,23 @@ void Manager::commitGammaRamps(int temperature)
     const auto outs = kwinApp()->platform()->outputs();
 
     for (auto *o : outs) {
-        int rampsize = o->getGammaRampSize();
+        int rampsize = o->gammaRampSize();
         GammaRamp ramp(rampsize);
 
         /*
          * The gamma calculation below is based on the Redshift app:
          * https://github.com/jonls/redshift
          */
+        uint16_t *red = ramp.red();
+        uint16_t *green = ramp.green();
+        uint16_t *blue = ramp.blue();
 
         // linear default state
         for (int i = 0; i < rampsize; i++) {
                 uint16_t value = (double)i / rampsize * (UINT16_MAX + 1);
-                ramp.red[i] = value;
-                ramp.green[i] = value;
-                ramp.blue[i] = value;
+                red[i] = value;
+                green[i] = value;
+                blue[i] = value;
         }
 
         // approximate white point
@@ -538,9 +613,9 @@ void Manager::commitGammaRamps(int temperature)
         whitePoint[2] = (1. - alpha) * blackbodyColor[bbCIndex + 2] + alpha * blackbodyColor[bbCIndex + 5];
 
         for (int i = 0; i < rampsize; i++) {
-            ramp.red[i] = (double)ramp.red[i] / (UINT16_MAX+1) * whitePoint[0] * (UINT16_MAX+1);
-            ramp.green[i] = (double)ramp.green[i] / (UINT16_MAX+1) * whitePoint[1] * (UINT16_MAX+1);
-            ramp.blue[i] = (double)ramp.blue[i] / (UINT16_MAX+1) * whitePoint[2] * (UINT16_MAX+1);
+            red[i] = qreal(red[i]) / (UINT16_MAX+1) * whitePoint[0] * (UINT16_MAX+1);
+            green[i] = qreal(green[i]) / (UINT16_MAX+1) * whitePoint[1] * (UINT16_MAX+1);
+            blue[i] = qreal(blue[i]) / (UINT16_MAX+1) * whitePoint[2] * (UINT16_MAX+1);
         }
 
         if (o->setGammaRamp(ramp)) {
@@ -627,7 +702,7 @@ bool Manager::changeConfiguration(QHash<QString, QVariant> data)
             return false;
         }
         int mo = iter1.value().toInt();
-        if (mo < 0 || 2 < mo) {
+        if (mo < 0 || 3 < mo) {
             return false;
         }
         NightColorMode moM;
@@ -640,6 +715,10 @@ bool Manager::changeConfiguration(QHash<QString, QVariant> data)
                 break;
             case 2:
                 moM = NightColorMode::Timings;
+                break;
+            case 3:
+                moM = NightColorMode::Constant;
+                break;
         }
         modeUpdate = m_mode != moM;
         mode = moM;
