@@ -21,7 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "constants.h"
 
 #include <QDateTime>
-#include <qmath.h>
+#include <QtMath>
 
 namespace KWin {
 namespace ColorCorrect {
