@@ -18,90 +18,89 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
+#pragma once
 
-#ifndef KWIN_COMPOSITE_H
-#define KWIN_COMPOSITE_H
-// KWin
 #include <kwinglobals.h>
-// KDE
-#include <KSelectionOwner>
-// Qt
+
 #include <QObject>
 #include <QElapsedTimer>
 #include <QTimer>
 #include <QBasicTimer>
 #include <QRegion>
 
-namespace KWin {
-
+namespace KWin
+{
 class Client;
+class CompositorSelectionOwner;
 class Scene;
 
-class CompositorSelectionOwner : public KSelectionOwner
+class KWIN_EXPORT Compositor : public QObject
 {
     Q_OBJECT
 public:
-    CompositorSelectionOwner(const char *selection);
-private:
-    friend class Compositor;
-    bool owning;
-private Q_SLOTS:
-    void looseOwnership();
-};
+    enum class State {
+        On = 0,
+        Off,
+        Starting,
+        Stopping
+    };
+
+    ~Compositor() override;
+    static Compositor *self();
 
-class KWIN_EXPORT Compositor : public QObject {
-    Q_OBJECT
-public:
-    enum SuspendReason { NoReasonSuspend = 0, UserSuspend = 1<<0, BlockRuleSuspend = 1<<1, ScriptSuspend = 1<<2, AllReasonSuspend = 0xff };
-    Q_DECLARE_FLAGS(SuspendReasons, SuspendReason)
-    ~Compositor();
     // when adding repaints caused by a window, you probably want to use
     // either Toplevel::addRepaint() or Toplevel::addWorkspaceRepaint()
     void addRepaint(const QRect& r);
     void addRepaint(const QRegion& r);
     void addRepaint(int x, int y, int w, int h);
+    void addRepaintFull();
+
+    /**
+     * Schedules a new repaint if no repaint is currently scheduled.
+     */
+    void scheduleRepaint();
+
+    /**
+     * Notifies the compositor that SwapBuffers() is about to be called.
+     * Rendering of the next frame will be deferred until bufferSwapComplete()
+     * is called.
+     */
+    void aboutToSwapBuffers();
+
+    /**
+     * Notifies the compositor that a pending buffer swap has completed.
+     */
+    void bufferSwapComplete();
+
+    /**
+     * Toggles compositing, that is if the Compositor is suspended it will be resumed
+     * and if the Compositor is active it will be suspended.
+     * Invoked by keybinding (shortcut default: Shift + Alt + F12).
+     */
+    virtual void toggleCompositing() = 0;
+
+    /**
+     * Re-initializes the Compositor completely.
+     * Connected to the D-Bus signal org.kde.KWin /KWin reinitCompositing
+     */
+    virtual void reinitialize();
+
     /**
      * Whether the Compositor is active. That is a Scene is present and the Compositor is
      * not shutting down itself.
-     **/
+     */
     bool isActive();
-    int xrrRefreshRate() const {
-        return m_xrrRefreshRate;
-    }
-    void setCompositeResetTimer(int msecs);
+    virtual int refreshRate() const = 0;
 
-    bool hasScene() const {
-        return m_scene != NULL;
-    }
-
-    /**
-     * Checks whether @p w is the Scene's overlay window.
-     **/
-    bool checkForOverlayWindow(WId w) const;
-    /**
-     * @returns Whether the Scene's Overlay X Window is visible.
-     **/
-    bool isOverlayWindowVisible() const;
-
-    Scene *scene() {
+    Scene *scene() const {
         return m_scene;
     }
 
-    /**
-     * @brief Checks whether the Compositor has already been created by the Workspace.
-     *
-     * This method can be used to check whether self will return the Compositor instance or @c null.
-     *
-     * @return bool @c true if the Compositor has been created, @c false otherwise
-     **/
-    static bool isCreated() {
-        return s_compositor != NULL;
-    }
     /**
      * @brief Static check to test whether the Compositor is available and active.
      *
      * @return bool @c true if there is a Compositor and it is active, @c false otherwise
-     **/
+     */
     static bool compositing() {
         return s_compositor != NULL && s_compositor->isActive();
     }
@@ -110,8 +109,101 @@ public:
     void keepSupportProperty(xcb_atom_t atom);
     void removeSupportProperty(xcb_atom_t atom);
 
-public Q_SLOTS:
-    void addRepaintFull();
+Q_SIGNALS:
+    void compositingToggled(bool active);
+    void aboutToDestroy();
+    void aboutToToggleCompositing();
+    void sceneCreated();
+    void bufferSwapCompleted();
+
+protected:
+    explicit Compositor(QObject *parent = nullptr);
+    void timerEvent(QTimerEvent *te) override;
+
+    virtual void start() = 0;
+    void stop();
+
+    /**
+     * @brief Prepares start.
+     * @return bool @c true if start should be continued and @c if not.
+     */
+    bool setupStart();
+    /**
+     * Continues the startup after Scene And Workspace are created
+     */
+    void startupWithWorkspace();
+    virtual void performCompositing();
+
+    virtual void configChanged();
+
+    void destroyCompositorSelection();
+
+    static Compositor *s_compositor;
+
+private:
+    void claimCompositorSelection();
+
+    void setupX11Support();
+
+    void setCompositeTimer();
+    bool windowRepaintsPending() const;
+
+    void releaseCompositorSelection();
+    void deleteUnusedSupportProperties();
+
+    State m_state;
+
+    QBasicTimer compositeTimer;
+    CompositorSelectionOwner *m_selectionOwner;
+    QTimer m_releaseSelectionTimer;
+    QList<xcb_atom_t> m_unusedSupportProperties;
+    QTimer m_unusedSupportPropertyTimer;
+    qint64 vBlankInterval, fpsInterval;
+    QRegion repaints_region;
+
+    qint64 m_timeSinceLastVBlank;
+
+    Scene *m_scene;
+
+    bool m_bufferSwapPending;
+    bool m_composeAtSwapCompletion;
+
+    int m_framesToTestForSafety = 3;
+    QElapsedTimer m_monotonicClock;
+};
+
+class KWIN_EXPORT WaylandCompositor : public Compositor
+{
+    Q_OBJECT
+public:
+    static WaylandCompositor *create(QObject *parent = nullptr);
+
+    int refreshRate() const override;
+
+    void toggleCompositing() override;
+
+protected:
+    void start() override;
+
+private:
+    explicit WaylandCompositor(QObject *parent);
+};
+
+class KWIN_EXPORT X11Compositor : public Compositor
+{
+    Q_OBJECT
+public:
+    enum SuspendReason {
+        NoReasonSuspend     = 0,
+        UserSuspend         = 1 << 0,
+        BlockRuleSuspend    = 1 << 1,
+        ScriptSuspend       = 1 << 2,
+        AllReasonSuspend    = 0xff
+    };
+    Q_DECLARE_FLAGS(SuspendReasons, SuspendReason)
+
+    static X11Compositor *create(QObject *parent = nullptr);
+
     /**
      * @brief Suspends the Compositor if it is currently active.
      *
@@ -121,8 +213,9 @@ public Q_SLOTS:
      * @return void
      * @see resume
      * @see isActive
-     **/
-    void suspend(Compositor::SuspendReason reason);
+     */
+    Q_INVOKABLE void suspend(SuspendReason reason);
+
     /**
      * @brief Resumes the Compositor if it is currently suspended.
      *
@@ -139,103 +232,42 @@ public Q_SLOTS:
      * @see isActive
      * @see isCompositingPossible
      * @see isOpenGLBroken
-     **/
-    void resume(Compositor::SuspendReason reason);
-    /**
-     * Actual slot to perform the toggling compositing.
-     * That is if the Compositor is suspended it will be resumed and if the Compositor is active
-     * it will be suspended.
-     * Invoked primarily by the keybinding.
-     * TODO: make private slot
-     **/
-    void slotToggleCompositing();
-    /**
-     * Re-initializes the Compositor completely.
-     * Connected to the D-Bus signal org.kde.KWin /KWin reinitCompositing
-     **/
-    void slotReinitialize();
-    /**
-     * Schedules a new repaint if no repaint is currently scheduled.
-     **/
-    void scheduleRepaint();
-    void updateCompositeBlocking();
-    void updateCompositeBlocking(KWin::Client* c);
+     */
+    Q_INVOKABLE void resume(SuspendReason reason);
+
+    void toggleCompositing() override;
+    void reinitialize() override;
+
+    void configChanged() override;
 
     /**
-     * Notifies the compositor that SwapBuffers() is about to be called.
-     * Rendering of the next frame will be deferred until bufferSwapComplete()
-     * is called.
-     **/
-    void aboutToSwapBuffers();
+     * Checks whether @p w is the Scene's overlay window.
+     */
+    bool checkForOverlayWindow(WId w) const;
 
     /**
-     * Notifies the compositor that a pending buffer swap has completed.
-     **/
-    void bufferSwapComplete();
+     * @returns Whether the Scene's Overlay X Window is visible.
+     */
+    bool isOverlayWindowVisible() const;
 
-Q_SIGNALS:
-    void compositingToggled(bool active);
-    void aboutToDestroy();
-    void aboutToToggleCompositing();
-    void sceneCreated();
-    void bufferSwapCompleted();
+    int refreshRate() const override;
+
+    void updateClientCompositeBlocking(Client *client = nullptr);
+
+    static X11Compositor *self();
 
 protected:
-    void timerEvent(QTimerEvent *te);
-
-private Q_SLOTS:
-    void setup();
-    /**
-     * Called from setupCompositing() when the CompositingPrefs are ready.
-     **/
-    void slotCompositingOptionsInitialized();
-    void finish();
-    /**
-     * Restarts the Compositor if running.
-     * That is the Compositor will be stopped and started again.
-     **/
-    void restart();
-    void performCompositing();
-    void slotConfigChanged();
-    void releaseCompositorSelection();
-    void deleteUnusedSupportProperties();
+    void start() override;
+    void performCompositing() override;
 
 private:
-    void claimCompositorSelection();
-    void setCompositeTimer();
-    bool windowRepaintsPending() const;
-    /**
-     * Continues the startup after Scene And Workspace are created
-     **/
-    void startupWithWorkspace();
-    void setupX11Support();
-
+    explicit X11Compositor(QObject *parent);
     /**
      * Whether the Compositor is currently suspended, 8 bits encoding the reason
-     **/
+     */
     SuspendReasons m_suspended;
 
-    QBasicTimer compositeTimer;
-    CompositorSelectionOwner* cm_selection;
-    QTimer m_releaseSelectionTimer;
-    QList<xcb_atom_t> m_unusedSupportProperties;
-    QTimer m_unusedSupportPropertyTimer;
-    qint64 vBlankInterval, fpsInterval;
     int m_xrrRefreshRate;
-    QRegion repaints_region;
-
-    QTimer compositeResetTimer; // for compressing composite resets
-    bool m_finishing; // finish() sets this variable while shutting down
-    bool m_starting; // start() sets this variable while starting
-    qint64 m_timeSinceLastVBlank;
-    Scene *m_scene;
-    bool m_bufferSwapPending;
-    bool m_composeAtSwapCompletion;
-    int m_framesToTestForSafety = 3;
-    QElapsedTimer m_monotonicClock;
-
-    KWIN_SINGLETON_VARIABLE(Compositor, s_compositor)
 };
-}
 
-# endif // KWIN_COMPOSITE_H
+}
