@@ -43,7 +43,6 @@ Deleted::Deleted()
     , m_minimized(false)
     , m_modal(false)
     , m_wasClient(false)
-    , m_wasCurrentTab(true)
     , m_decorationRenderer(nullptr)
     , m_fullscreen(false)
     , m_keepAbove(false)
@@ -61,7 +60,7 @@ Deleted::~Deleted()
 {
     if (delete_refcount != 0)
         qCCritical(KWIN_CORE) << "Deleted client has non-zero reference count (" << delete_refcount << ")";
-    assert(delete_refcount == 0);
+    Q_ASSERT(delete_refcount == 0);
     if (workspace()) {
         workspace()->removeDeleted(this);
     }
@@ -93,7 +92,7 @@ void Deleted::discard()
 
 void Deleted::copyToDeleted(Toplevel* c)
 {
-    assert(dynamic_cast< Deleted* >(c) == NULL);
+    Q_ASSERT(dynamic_cast< Deleted* >(c) == NULL);
     Toplevel::copyToDeleted(c);
     desk = c->desktop();
     m_desktops = c->desktops();
@@ -131,7 +130,6 @@ void Deleted::copyToDeleted(Toplevel* c)
             connect(c, &AbstractClient::windowClosed, this, &Deleted::mainClientClosed);
         }
         m_fullscreen = client->isFullScreen();
-        m_wasCurrentTab = client->isCurrentTab();
         m_keepAbove = client->keepAbove();
         m_keepBelow = client->keepBelow();
         m_caption = client->caption();
