@@ -51,7 +51,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <Plasma/Theme>
 
-#include <assert.h>
 #include "composite.h"
 #include "xcbutils.h"
 #include "platform.h"
@@ -212,6 +211,7 @@ EffectsHandlerImpl::EffectsHandlerImpl(Compositor *compositor, Scene *scene)
 #endif
     connect(ScreenEdges::self(), &ScreenEdges::approaching, this, &EffectsHandler::screenEdgeApproaching);
     connect(ScreenLockerWatcher::self(), &ScreenLockerWatcher::locked, this, &EffectsHandler::screenLockingChanged);
+    connect(ScreenLockerWatcher::self(), &ScreenLockerWatcher::aboutToLock, this, &EffectsHandler::screenAboutToLock);
 
     connect(kwinApp(), &Application::x11ConnectionChanged, this,
         [this] {
@@ -561,8 +561,7 @@ void EffectsHandlerImpl::slotClientShown(KWin::Toplevel *t)
     Client *c = static_cast<Client*>(t);
     disconnect(c, &Toplevel::windowShown, this, &EffectsHandlerImpl::slotClientShown);
     setupClientConnections(c);
-    if (!c->tabGroup()) // the "window" has already been there
-        emit windowAdded(c->effectWindow());
+    emit windowAdded(c->effectWindow());
 }
 
 void EffectsHandlerImpl::slotShellClientShown(Toplevel *t)
@@ -676,7 +675,7 @@ bool EffectsHandlerImpl::doGrabKeyboard()
 
 void EffectsHandlerImpl::ungrabKeyboard()
 {
-    assert(keyboard_grab_effect != NULL);
+    Q_ASSERT(keyboard_grab_effect != NULL);
     doUngrabKeyboard();
     keyboard_grab_effect = NULL;
 }
@@ -730,7 +729,7 @@ bool EffectsHandlerImpl::isMouseInterception() const
 }
 
 
-bool EffectsHandlerImpl::touchDown(quint32 id, const QPointF &pos, quint32 time)
+bool EffectsHandlerImpl::touchDown(qint32 id, const QPointF &pos, quint32 time)
 {
     // TODO: reverse call order?
     for (auto it = loaded_effects.constBegin(); it != loaded_effects.constEnd(); ++it) {
@@ -741,7 +740,7 @@ bool EffectsHandlerImpl::touchDown(quint32 id, const QPointF &pos, quint32 time)
     return false;
 }
 
-bool EffectsHandlerImpl::touchMotion(quint32 id, const QPointF &pos, quint32 time)
+bool EffectsHandlerImpl::touchMotion(qint32 id, const QPointF &pos, quint32 time)
 {
     // TODO: reverse call order?
     for (auto it = loaded_effects.constBegin(); it != loaded_effects.constEnd(); ++it) {
@@ -752,7 +751,7 @@ bool EffectsHandlerImpl::touchMotion(quint32 id, const QPointF &pos, quint32 tim
     return false;
 }
 
-bool EffectsHandlerImpl::touchUp(quint32 id, quint32 time)
+bool EffectsHandlerImpl::touchUp(qint32 id, quint32 time)
 {
     // TODO: reverse call order?
     for (auto it = loaded_effects.constBegin(); it != loaded_effects.constEnd(); ++it) {
@@ -1188,16 +1187,18 @@ QList< int > EffectsHandlerImpl::currentTabBoxDesktopList() const
 {
 #ifdef KWIN_BUILD_TABBOX
     return TabBox::TabBox::self()->currentDesktopList();
-#endif
+#else
     return QList< int >();
+#endif
 }
 
 int EffectsHandlerImpl::currentTabBoxDesktop() const
 {
 #ifdef KWIN_BUILD_TABBOX
     return TabBox::TabBox::self()->currentDesktop();
-#endif
+#else
     return -1;
+#endif
 }
 
 EffectWindow* EffectsHandlerImpl::currentTabBoxWindow() const
@@ -1854,7 +1855,6 @@ TOPLEVEL_HELPER(bool, isOutline, isOutline)
 CLIENT_HELPER_WITH_DELETED(bool, isMinimized, isMinimized, false)
 CLIENT_HELPER_WITH_DELETED(bool, isModal, isModal, false)
 CLIENT_HELPER_WITH_DELETED(bool, isFullScreen, isFullScreen, false)
-CLIENT_HELPER_WITH_DELETED(bool, isCurrentTab, isCurrentTab, false)
 CLIENT_HELPER_WITH_DELETED(bool, keepAbove, keepAbove, false)
 CLIENT_HELPER_WITH_DELETED(bool, keepBelow, keepBelow, false)
 CLIENT_HELPER_WITH_DELETED(QString, caption, caption, QString());
@@ -1862,6 +1862,12 @@ CLIENT_HELPER_WITH_DELETED(QVector<uint>, desktops, x11DesktopIds, QVector<uint>
 
 #undef CLIENT_HELPER_WITH_DELETED
 
+// legacy from tab groups, can be removed when no effects use this any more.
+bool EffectWindowImpl::isCurrentTab() const
+{
+    return true;
+}
+
 QString EffectWindowImpl::windowClass() const
 {
     return toplevel->resourceName() + QLatin1Char(' ') + toplevel->resourceClass();
@@ -2059,9 +2065,9 @@ void EffectWindowImpl::insertThumbnail(WindowThumbnailItem *item)
 {
     EffectWindow *w = effects->findWindow(item->wId());
     if (w) {
-        m_thumbnails.insert(item, QWeakPointer<EffectWindowImpl>(static_cast<EffectWindowImpl*>(w)));
+        m_thumbnails.insert(item, QPointer<EffectWindowImpl>(static_cast<EffectWindowImpl*>(w)));
     } else {
-        m_thumbnails.insert(item, QWeakPointer<EffectWindowImpl>());
+        m_thumbnails.insert(item, QPointer<EffectWindowImpl>());
     }
 }
 
