@@ -39,7 +39,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QVector2D>
 #include <QVector3D>
 
-#include <math.h>
+#include <cmath>
 
 #include <kwinglutils.h>
 #include <kwinglplatform.h>
@@ -101,6 +101,16 @@ CubeEffect::CubeEffect()
     connect(effects, &EffectsHandler::tabBoxAdded, this, &CubeEffect::slotTabBoxAdded);
     connect(effects, &EffectsHandler::tabBoxClosed, this, &CubeEffect::slotTabBoxClosed);
     connect(effects, &EffectsHandler::tabBoxUpdated, this, &CubeEffect::slotTabBoxUpdated);
+    connect(effects, &EffectsHandler::screenAboutToLock, this, [this]() {
+        // Set active(false) does not release key grabs until the animation completes
+        // As we know the lockscreen is trying to grab them, release them early
+        // all other grabs are released in the normal way
+        setActive(false);
+        if (keyboard_grab) {
+            effects->ungrabKeyboard();
+            keyboard_grab = false;
+        }
+    });
 
     reconfigure(ReconfigureAll);
 }
@@ -1273,7 +1283,7 @@ void CubeEffect::paintWindow(EffectWindow* w, int mask, QRegion region, WindowPa
                     quadSize = 150.0f;
                 else
                     quadSize = 250.0f;
-                foreach (const QRect & paintRect, paint.rects()) {
+                for (const QRect &paintRect : paint) {
                     for (int i = 0; i <= (paintRect.height() / quadSize); i++) {
                         for (int j = 0; j <= (paintRect.width() / quadSize); j++) {
                             verts << qMin(paintRect.x() + (j + 1)*quadSize, (float)paintRect.x() + paintRect.width()) << paintRect.y() + i*quadSize;
