@@ -27,8 +27,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../presentwindows/presentwindows_proxy.h"
 #include "../effect_builtins.h"
 
-#include <math.h>
-
 #include <QAction>
 #include <QApplication>
 #include <KGlobalAccel>
@@ -44,6 +42,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <KWayland/Server/surface_interface.h>
 
+#include <cmath>
+
 namespace KWin
 {
 
@@ -88,6 +88,14 @@ DesktopGridEffect::DesktopGridEffect()
     connect(effects, &EffectsHandler::windowGeometryShapeChanged, this, &DesktopGridEffect::slotWindowGeometryShapeChanged);
     connect(effects, &EffectsHandler::numberScreensChanged, this, &DesktopGridEffect::setup);
 
+    connect(effects, &EffectsHandler::screenAboutToLock, this, [this]() {
+        setActive(false);
+        if (keyboardGrab) {
+            effects->ungrabKeyboard();
+            keyboardGrab = false;
+        }
+    });
+
     // Load all other configuration details
     reconfigure(ReconfigureAll);
 }
@@ -1428,10 +1436,6 @@ bool DesktopGridEffect::isRelevantWithPresentWindows(EffectWindow *w) const
         return false;
     }
 
-    if (!w->isCurrentTab()) {
-        return false;
-    }
-
     if (!w->isOnCurrentActivity()) {
         return false;
     }
