@@ -75,6 +75,10 @@ FlipSwitchEffect::FlipSwitchEffect()
     connect(effects, &EffectsHandler::tabBoxClosed, this, &FlipSwitchEffect::slotTabBoxClosed);
     connect(effects, &EffectsHandler::tabBoxUpdated, this, &FlipSwitchEffect::slotTabBoxUpdated);
     connect(effects, &EffectsHandler::tabBoxKeyEvent, this, &FlipSwitchEffect::slotTabBoxKeyEvent);
+    connect(effects, &EffectsHandler::screenAboutToLock, this, [this]() {
+        setActive(false, AllDesktopsMode);
+        setActive(false, CurrentDesktopMode);
+    });
 }
 
 FlipSwitchEffect::~FlipSwitchEffect()
@@ -366,8 +370,6 @@ void FlipSwitchEffect::prePaintWindow(EffectWindow* w, WindowPrePaintData& data,
                 w->enablePainting(EffectWindow::PAINT_DISABLED_BY_DESKTOP);
             if (w->isMinimized())
                 w->enablePainting(EffectWindow::PAINT_DISABLED_BY_MINIMIZE);
-            if (!w->isCurrentTab())
-                w->enablePainting(EffectWindow::PAINT_DISABLED_BY_TAB_GROUP);
         } else {
             if ((m_start || m_stop) && !w->isDesktop() && w->isOnCurrentDesktop())
                 data.setTranslucent();
