@@ -32,11 +32,11 @@ class HighlightWindowEffect
     Q_OBJECT
 public:
     HighlightWindowEffect();
-    virtual ~HighlightWindowEffect();
+    ~HighlightWindowEffect() override;
 
-    virtual void prePaintWindow(EffectWindow* w, WindowPrePaintData& data, int time);
-    virtual void paintWindow(EffectWindow* w, int mask, QRegion region, WindowPaintData& data);
-    virtual bool isActive() const;
+    void prePaintWindow(EffectWindow* w, WindowPrePaintData& data, int time) override;
+    void paintWindow(EffectWindow* w, int mask, QRegion region, WindowPaintData& data) override;
+    bool isActive() const override;
 
     int requestedEffectChainPosition() const override {
         return 70;
