@@ -36,7 +36,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QPainter>
 
-#include <math.h>
+#include <cmath>
 
 namespace KWin
 {
