@@ -33,7 +33,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QPainter>
 
-#include <math.h>
+#include <cmath>
 
 #ifdef KWIN_HAVE_XRENDER_COMPOSITING
 #include <xcb/render.h>
