@@ -31,9 +31,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QMouseEvent>
 #include <netwm_def.h>
 
-#include <math.h>
-#include <assert.h>
-#include <limits.h>
 #include <QApplication>
 #include <QQmlContext>
 #include <QQmlEngine>
@@ -45,6 +42,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QVector2D>
 #include <QVector4D>
 
+#include <climits>
+#include <cmath>
+
 namespace KWin
 {
 
@@ -111,6 +111,9 @@ PresentWindowsEffect::PresentWindowsEffect()
                 reCreateGrids();
         }
     );
+    connect(effects, &EffectsHandler::screenAboutToLock, this, [this]() {
+        setActive(false);
+    });
 }
 
 PresentWindowsEffect::~PresentWindowsEffect()
@@ -286,8 +289,6 @@ void PresentWindowsEffect::prePaintWindow(EffectWindow *w, WindowPrePaintData &d
         }
         w->enablePainting(EffectWindow::PAINT_DISABLED_BY_MINIMIZE);   // Display always
         w->enablePainting(EffectWindow::PAINT_DISABLED_BY_DESKTOP);
-        if (winData->visible)
-            w->enablePainting(EffectWindow::PAINT_DISABLED_BY_TAB_GROUP);
 
         // Calculate window's opacity
         // TODO: Minimized windows or windows not on the current desktop are only 75% visible?
@@ -642,7 +643,7 @@ void PresentWindowsEffect::inputEventUpdate(const QPoint &pos, QEvent::Type type
         setHighlightedWindow(highlightCandidate);
 }
 
-bool PresentWindowsEffect::touchDown(quint32 id, const QPointF &pos, quint32 time)
+bool PresentWindowsEffect::touchDown(qint32 id, const QPointF &pos, quint32 time)
 {
     Q_UNUSED(time)
     if (!m_activated) {
@@ -657,7 +658,7 @@ bool PresentWindowsEffect::touchDown(quint32 id, const QPointF &pos, quint32 tim
     return true;
 }
 
-bool PresentWindowsEffect::touchMotion(quint32 id, const QPointF &pos, quint32 time)
+bool PresentWindowsEffect::touchMotion(qint32 id, const QPointF &pos, quint32 time)
 {
     Q_UNUSED(id)
     Q_UNUSED(time)
@@ -671,7 +672,7 @@ bool PresentWindowsEffect::touchMotion(quint32 id, const QPointF &pos, quint32 t
     return true;
 }
 
-bool PresentWindowsEffect::touchUp(quint32 id, quint32 time)
+bool PresentWindowsEffect::touchUp(qint32 id, quint32 time)
 {
     Q_UNUSED(id)
     Q_UNUSED(time)
@@ -719,6 +720,11 @@ void PresentWindowsEffect::mouseActionWindow(WindowMouseAction& action)
                 m_highlightedWindow->minimize();
         }
         break;
+    case WindowCloseAction:
+        if (m_highlightedWindow) {
+            m_highlightedWindow->closeWindow();
+        }
+        break;
     default:
         break;
     }
@@ -1064,7 +1070,7 @@ void PresentWindowsEffect::calculateWindowTransformationsClosest(EffectWindowLis
             const int dist = distance(pos, slotCenters[i]);
             if (dist < slotCandidateDistance) { // window is interested in this slot
                 EffectWindow *occupier = takenSlots[i];
-                assert(occupier != w);
+                Q_ASSERT(occupier != w);
                 if (!occupier || dist < distance((otherPos = occupier->geometry().center()), slotCenters[i])) {
                     // either nobody lives here, or we're better - takeover the slot if it's our best
                     slotCandidate = i;
@@ -1072,7 +1078,7 @@ void PresentWindowsEffect::calculateWindowTransformationsClosest(EffectWindowLis
                 }
             }
         }
-        assert(slotCandidate != -1);
+        Q_ASSERT(slotCandidate != -1);
         if (takenSlots[slotCandidate])
             tmpList << takenSlots[slotCandidate]; // occupier needs a new home now :p
         tmpList.removeAll(w);
@@ -1124,7 +1130,7 @@ void PresentWindowsEffect::calculateWindowTransformationsKompose(EffectWindowLis
     QRect availRect = effects->clientArea(ScreenArea, screen, effects->currentDesktop());
     if (m_showPanel)   // reserve space for the panel
         availRect = effects->clientArea(MaximizeArea, screen, effects->currentDesktop());
-    qSort(windowlist);   // The location of the windows should not depend on the stacking order
+    std::sort(windowlist.begin(), windowlist.end());   // The location of the windows should not depend on the stacking order
 
     // Following code is taken from Kompose 0.5.4, src/komposelayout.cpp
 
@@ -1271,7 +1277,7 @@ void PresentWindowsEffect::calculateWindowTransformationsNatural(EffectWindowLis
 
     // As we are using pseudo-random movement (See "slot") we need to make sure the list
     // is always sorted the same way no matter which window is currently active.
-    qSort(windowlist);
+    std::sort(windowlist.begin(), windowlist.end());
 
     QRect area = effects->clientArea(ScreenArea, screen, effects->currentDesktop());
     if (m_showPanel)   // reserve space for the panel
@@ -1612,7 +1618,7 @@ void PresentWindowsEffect::setActive(bool active)
             DataHash::iterator winData = m_windowData.find(w);
             if (winData != m_windowData.end())
                 winData->visible = (w->isOnDesktop(desktop) || w->isOnAllDesktops()) &&
-                                    !w->isMinimized() && (w->isCurrentTab() || winData->visible);
+                                    !w->isMinimized();
         }
         if (m_closeView)
             m_closeView->hide();
@@ -1673,8 +1679,6 @@ bool PresentWindowsEffect::isSelectableWindow(EffectWindow *w)
         return false;
     if (!w->acceptsFocus())
         return false;
-    if (!w->isCurrentTab())
-        return false;
     if (w->isSkipSwitcher())
         return false;
     if (m_closeView && w == effects->findWindow(m_closeView->winId()))
