@@ -33,10 +33,10 @@ class ShowFpsEffectConfig : public KCModule
     Q_OBJECT
 public:
     explicit ShowFpsEffectConfig(QWidget* parent = 0, const QVariantList& args = QVariantList());
-    ~ShowFpsEffectConfig();
+    ~ShowFpsEffectConfig() override;
 
 public Q_SLOTS:
-    virtual void save();
+    void save() override;
 
 private:
     Ui::ShowFpsEffectConfigForm *m_ui;
