@@ -33,12 +33,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "client.h"
 #include "effects.h"
 
-#include <assert.h>
 #include <kstartupinfo.h>
 #include <KWindowSystem>
 #include <QDebug>
 
-
 /*
  TODO
  Rename as many uses of 'transient' as possible (hasTransient->hasSubwindow,etc.),
@@ -52,14 +50,14 @@ namespace KWin
 // Group
 //********************************************
 
-Group::Group(Window leader_P)
+Group::Group(xcb_window_t leader_P)
     :   leader_client(NULL),
         leader_wid(leader_P),
         leader_info(NULL),
         user_time(-1U),
         refcount(0)
 {
-    if (leader_P != None) {
+    if (leader_P != XCB_WINDOW_NONE) {
         leader_client = workspace()->findClient(Predicate::WindowMatch, leader_P);
         leader_info = new NETWinInfo(connection(), leader_P, rootWindow(),
                                       0, NET::WM2StartupId);
@@ -78,7 +76,7 @@ QIcon Group::icon() const
 {
     if (leader_client != NULL)
         return leader_client->icon();
-    else if (leader_wid != None) {
+    else if (leader_wid != XCB_WINDOW_NONE) {
         QIcon ic;
         NETWinInfo info(connection(), leader_wid, rootWindow(), NET::WMIcon, NET::WM2IconPixmap);
         auto readIcon = [&ic, &info, this](int size, bool scale = true) {
@@ -135,13 +133,13 @@ void Group::deref()
 
 void Group::gotLeader(Client* leader_P)
 {
-    assert(leader_P->window() == leader_wid);
+    Q_ASSERT(leader_P->window() == leader_wid);
     leader_client = leader_P;
 }
 
 void Group::lostLeader()
 {
-    assert(!_members.contains(leader_client));
+    Q_ASSERT(!_members.contains(leader_client));
     leader_client = NULL;
     if (_members.isEmpty()) {
         workspace()->removeGroup(this);
@@ -155,7 +153,7 @@ void Group::lostLeader()
 
 Group* Workspace::findGroup(xcb_window_t leader) const
 {
-    assert(leader != None);
+    Q_ASSERT(leader != XCB_WINDOW_NONE);
     for (GroupList::ConstIterator it = groups.constBegin();
             it != groups.constEnd();
             ++it)
@@ -236,7 +234,7 @@ void Workspace::updateMinimizedOfTransients(AbstractClient* c)
 
 /**
  * Sets the client \a c's transient windows' on_all_desktops property to \a on_all_desktops.
- **/
+ */
 void Workspace::updateOnAllDesktopsOfTransients(AbstractClient* c)
 {
     for (auto it = c->transients().constBegin();
@@ -438,7 +436,7 @@ void Client::setTransient(xcb_window_t new_transient_for_id)
         m_transientForId = new_transient_for_id;
         if (m_transientForId != XCB_WINDOW_NONE && !groupTransient()) {
             transient_for = workspace()->findClient(Predicate::WindowMatch, m_transientForId);
-            assert(transient_for != NULL);   // verifyTransient() had to check this
+            Q_ASSERT(transient_for != NULL);   // verifyTransient() had to check this
             transient_for->addTransient(this);
         } // checkGroup() will check 'check_active_modal'
         setTransientFor(transient_for);
@@ -583,7 +581,7 @@ void Client::checkGroupTransients()
 
 /**
  * Check that the window is not transient for itself, and similar nonsense.
- **/
+ */
 xcb_window_t Client::verifyTransientFor(xcb_window_t new_transient_for, bool set)
 {
     xcb_window_t new_property_value = new_transient_for;
@@ -811,7 +809,7 @@ void Client::checkGroup(Group* set_group, bool force)
             // try creating group with other windows with the same client leader
             Group* new_group = workspace()->findClientLeaderGroup(this);
             if (new_group == NULL)
-                new_group = new Group(None);
+                new_group = new Group(XCB_WINDOW_NONE);
             if (new_group != in_group) {
                 if (in_group != NULL)
                     in_group->removeMember(this);
@@ -828,7 +826,7 @@ void Client::checkGroup(Group* set_group, bool force)
                 in_group = NULL;
             }
             if (new_group == NULL)
-                new_group = new Group(None);
+                new_group = new Group(XCB_WINDOW_NONE);
             if (in_group != new_group) {
                 in_group = new_group;
                 in_group->addMember(this);
