@@ -4,6 +4,7 @@
 
 Copyright (C) 2013 Martin Gräßlin <mgraesslin@kde.org>
 Copyright (C) 2018 Roman Gilg <subdiff@gmail.com>
+Copyright (C) 2019 Vlad Zagorodniy <vladzzag@gmail.com>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -91,7 +92,7 @@ bool InputEventFilter::keyEvent(QKeyEvent *event)
     return false;
 }
 
-bool InputEventFilter::touchDown(quint32 id, const QPointF &point, quint32 time)
+bool InputEventFilter::touchDown(qint32 id, const QPointF &point, quint32 time)
 {
     Q_UNUSED(id)
     Q_UNUSED(point)
@@ -99,7 +100,7 @@ bool InputEventFilter::touchDown(quint32 id, const QPointF &point, quint32 time)
     return false;
 }
 
-bool InputEventFilter::touchMotion(quint32 id, const QPointF &point, quint32 time)
+bool InputEventFilter::touchMotion(qint32 id, const QPointF &point, quint32 time)
 {
     Q_UNUSED(id)
     Q_UNUSED(point)
@@ -107,7 +108,7 @@ bool InputEventFilter::touchMotion(quint32 id, const QPointF &point, quint32 tim
     return false;
 }
 
-bool InputEventFilter::touchUp(quint32 id, quint32 time)
+bool InputEventFilter::touchUp(qint32 id, quint32 time)
 {
     Q_UNUSED(id)
     Q_UNUSED(time)
@@ -292,7 +293,7 @@ public:
         }
         return true;
     }
-    bool touchDown(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchDown(qint32 id, const QPointF &pos, quint32 time) override {
         if (!waylandServer()->isScreenLocked()) {
             return false;
         }
@@ -303,7 +304,7 @@ public:
         }
         return true;
     }
-    bool touchMotion(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchMotion(qint32 id, const QPointF &pos, quint32 time) override {
         if (!waylandServer()->isScreenLocked()) {
             return false;
         }
@@ -317,7 +318,7 @@ public:
         }
         return true;
     }
-    bool touchUp(quint32 id, quint32 time) override {
+    bool touchUp(qint32 id, quint32 time) override {
         if (!waylandServer()->isScreenLocked()) {
             return false;
         }
@@ -418,19 +419,19 @@ public:
         static_cast< EffectsHandlerImpl* >(effects)->grabbedKeyboardEvent(event);
         return true;
     }
-    bool touchDown(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchDown(qint32 id, const QPointF &pos, quint32 time) override {
         if (!effects) {
             return false;
         }
         return static_cast< EffectsHandlerImpl* >(effects)->touchDown(id, pos, time);
     }
-    bool touchMotion(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchMotion(qint32 id, const QPointF &pos, quint32 time) override {
         if (!effects) {
             return false;
         }
         return static_cast< EffectsHandlerImpl* >(effects)->touchMotion(id, pos, time);
     }
-    bool touchUp(quint32 id, quint32 time) override {
+    bool touchUp(qint32 id, quint32 time) override {
         if (!effects) {
             return false;
         }
@@ -480,7 +481,7 @@ public:
         return true;
     }
 
-    bool touchDown(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchDown(qint32 id, const QPointF &pos, quint32 time) override {
         Q_UNUSED(id)
         Q_UNUSED(pos)
         Q_UNUSED(time)
@@ -491,7 +492,7 @@ public:
         return true;
     }
 
-    bool touchMotion(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchMotion(qint32 id, const QPointF &pos, quint32 time) override {
         Q_UNUSED(time)
         AbstractClient *c = workspace()->moveResizeClient();
         if (!c) {
@@ -507,7 +508,7 @@ public:
         return true;
     }
 
-    bool touchUp(quint32 id, quint32 time) override {
+    bool touchUp(qint32 id, quint32 time) override {
         Q_UNUSED(time)
         AbstractClient *c = workspace()->moveResizeClient();
         if (!c) {
@@ -523,7 +524,7 @@ public:
         return true;
     }
 private:
-    quint32 m_id = 0;
+    qint32 m_id = 0;
     bool m_set = false;
 };
 
@@ -597,7 +598,7 @@ public:
         return true;
     }
 
-    bool touchDown(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchDown(qint32 id, const QPointF &pos, quint32 time) override {
         Q_UNUSED(time)
         if (!isActive()) {
             return false;
@@ -606,7 +607,7 @@ public:
         return true;
     }
 
-    bool touchMotion(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchMotion(qint32 id, const QPointF &pos, quint32 time) override {
         Q_UNUSED(time)
         if (!isActive()) {
             return false;
@@ -618,7 +619,7 @@ public:
         return true;
     }
 
-    bool touchUp(quint32 id, quint32 time) override {
+    bool touchUp(qint32 id, quint32 time) override {
         Q_UNUSED(time)
         if (!isActive()) {
             return false;
@@ -916,7 +917,7 @@ class InternalWindowEventFilter : public InputEventFilter {
         return false;
     }
 
-    bool touchDown(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchDown(qint32 id, const QPointF &pos, quint32 time) override {
         auto seat = waylandServer()->seat();
         if (seat->isTouchSequence()) {
             // something else is getting the events
@@ -946,7 +947,7 @@ class InternalWindowEventFilter : public InputEventFilter {
         QCoreApplication::sendEvent(internal.data(), &e);
         return true;
     }
-    bool touchMotion(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchMotion(qint32 id, const QPointF &pos, quint32 time) override {
         auto touch = input()->touch();
         auto internal = touch->internalWindow();
         if (!internal) {
@@ -967,7 +968,7 @@ class InternalWindowEventFilter : public InputEventFilter {
         QCoreApplication::instance()->sendEvent(internal.data(), &e);
         return true;
     }
-    bool touchUp(quint32 id, quint32 time) override {
+    bool touchUp(qint32 id, quint32 time) override {
         auto touch = input()->touch();
         auto internal = touch->internalWindow();
         if (!internal) {
@@ -1069,7 +1070,7 @@ public:
         }
         return true;
     }
-    bool touchDown(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchDown(qint32 id, const QPointF &pos, quint32 time) override {
         auto seat = waylandServer()->seat();
         if (seat->isTouchSequence()) {
             return false;
@@ -1099,7 +1100,7 @@ public:
         }
         return true;
     }
-    bool touchMotion(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchMotion(qint32 id, const QPointF &pos, quint32 time) override {
         Q_UNUSED(time)
         auto decoration = input()->touch()->decoration();
         if (!decoration) {
@@ -1120,7 +1121,7 @@ public:
         decoration->client()->processDecorationMove(m_lastLocalTouchPos.toPoint(), pos.toPoint());
         return true;
     }
-    bool touchUp(quint32 id, quint32 time) override {
+    bool touchUp(qint32 id, quint32 time) override {
         Q_UNUSED(time);
         auto decoration = input()->touch()->decoration();
         if (!decoration) {
@@ -1200,7 +1201,7 @@ public:
         // always forward
         return false;
     }
-    bool touchDown(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchDown(qint32 id, const QPointF &pos, quint32 time) override {
         Q_UNUSED(time)
         // TODO: better check whether a touch sequence is in progress
         if (m_touchInProgress || waylandServer()->seat()->isTouchSequence()) {
@@ -1218,7 +1219,7 @@ public:
         }
         return false;
     }
-    bool touchMotion(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchMotion(qint32 id, const QPointF &pos, quint32 time) override {
         Q_UNUSED(time)
         if (m_touchInProgress && m_id == id) {
             ScreenEdges::self()->gestureRecognizer()->updateSwipeGesture(QSizeF(pos.x() - m_lastPos.x(), pos.y() - m_lastPos.y()));
@@ -1227,7 +1228,7 @@ public:
         }
         return false;
     }
-    bool touchUp(quint32 id, quint32 time) override {
+    bool touchUp(qint32 id, quint32 time) override {
         Q_UNUSED(time)
         if (m_touchInProgress && m_id == id) {
             ScreenEdges::self()->gestureRecognizer()->endSwipeGesture();
@@ -1238,14 +1239,14 @@ public:
     }
 private:
     bool m_touchInProgress = false;
-    quint32 m_id = 0;
+    qint32 m_id = 0;
     QPointF m_lastPos;
 };
 
 /**
  * This filter implements window actions. If the event should not be passed to the
  * current pointer window it will filter out the event
- **/
+ */
 class WindowActionInputFilter : public InputEventFilter
 {
 public:
@@ -1279,7 +1280,7 @@ public:
         }
         return false;
     }
-    bool touchDown(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchDown(qint32 id, const QPointF &pos, quint32 time) override {
         Q_UNUSED(id)
         Q_UNUSED(time)
         auto seat = waylandServer()->seat();
@@ -1301,7 +1302,7 @@ public:
 
 /**
  * The remaining default input filter which forwards events to other windows
- **/
+ */
 class ForwardInputFilter : public InputEventFilter
 {
 public:
@@ -1331,8 +1332,27 @@ public:
     bool wheelEvent(QWheelEvent *event) override {
         auto seat = waylandServer()->seat();
         seat->setTimestamp(event->timestamp());
-        const Qt::Orientation orientation = event->angleDelta().x() == 0 ? Qt::Vertical : Qt::Horizontal;
-        seat->pointerAxis(orientation, orientation == Qt::Horizontal ? event->angleDelta().x() : event->angleDelta().y());
+        auto _event = static_cast<WheelEvent *>(event);
+        KWayland::Server::PointerAxisSource source;
+        switch (_event->axisSource()) {
+        case KWin::InputRedirection::PointerAxisSourceWheel:
+            source = KWayland::Server::PointerAxisSource::Wheel;
+            break;
+        case KWin::InputRedirection::PointerAxisSourceFinger:
+            source = KWayland::Server::PointerAxisSource::Finger;
+            break;
+        case KWin::InputRedirection::PointerAxisSourceContinuous:
+            source = KWayland::Server::PointerAxisSource::Continuous;
+            break;
+        case KWin::InputRedirection::PointerAxisSourceWheelTilt:
+            source = KWayland::Server::PointerAxisSource::WheelTilt;
+            break;
+        case KWin::InputRedirection::PointerAxisSourceUnknown:
+        default:
+            source = KWayland::Server::PointerAxisSource::Unknown;
+            break;
+        }
+        seat->pointerAxisV5(_event->orientation(), _event->delta(), _event->discreteDelta(), source);
         return true;
     }
     bool keyEvent(QKeyEvent *event) override {
@@ -1349,7 +1369,7 @@ public:
         passToWaylandServer(event);
         return true;
     }
-    bool touchDown(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchDown(qint32 id, const QPointF &pos, quint32 time) override {
         if (!workspace()) {
             return false;
         }
@@ -1358,7 +1378,7 @@ public:
         input()->touch()->insertId(id, seat->touchDown(pos));
         return true;
     }
-    bool touchMotion(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchMotion(qint32 id, const QPointF &pos, quint32 time) override {
         if (!workspace()) {
             return false;
         }
@@ -1370,7 +1390,7 @@ public:
         }
         return true;
     }
-    bool touchUp(quint32 id, quint32 time) override {
+    bool touchUp(qint32 id, quint32 time) override {
         if (!workspace()) {
             return false;
         }
@@ -1514,7 +1534,7 @@ public:
         return true;
     }
 
-    bool touchDown(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchDown(qint32 id, const QPointF &pos, quint32 time) override {
         auto seat = waylandServer()->seat();
         if (seat->isDragPointer()) {
             return true;
@@ -1529,7 +1549,7 @@ public:
         input()->touch()->insertId(id, seat->touchDown(pos));
         return true;
     }
-    bool touchMotion(quint32 id, const QPointF &pos, quint32 time) override {
+    bool touchMotion(qint32 id, const QPointF &pos, quint32 time) override {
         auto seat = waylandServer()->seat();
         if (seat->isDragPointer()) {
             return true;
@@ -1568,7 +1588,7 @@ public:
         }
         return true;
     }
-    bool touchUp(quint32 id, quint32 time) override {
+    bool touchUp(qint32 id, quint32 time) override {
         auto seat = waylandServer()->seat();
         if (!seat->isDragTouch()) {
             return false;
@@ -1724,26 +1744,26 @@ void InputRedirection::setupWorkspace()
                             break;
                         }
                         // TODO: Fix time
-                        m_pointer->processAxis(axis, delta, 0);
+                        m_pointer->processAxis(axis, delta, 0, InputRedirection::PointerAxisSourceUnknown, 0);
                         waylandServer()->simulateUserActivity();
                     }
                 );
                 connect(device, &FakeInputDevice::touchDownRequested, this,
-                   [this] (quint32 id, const QPointF &pos) {
+                   [this] (qint32 id, const QPointF &pos) {
                        // TODO: Fix time
                        m_touch->processDown(id, pos, 0);
                         waylandServer()->simulateUserActivity();
                    }
                 );
                 connect(device, &FakeInputDevice::touchMotionRequested, this,
-                   [this] (quint32 id, const QPointF &pos) {
+                   [this] (qint32 id, const QPointF &pos) {
                        // TODO: Fix time
                        m_touch->processMotion(id, pos, 0);
                         waylandServer()->simulateUserActivity();
                    }
                 );
                 connect(device, &FakeInputDevice::touchUpRequested, this,
-                    [this] (quint32 id) {
+                    [this] (qint32 id) {
                         // TODO: Fix time
                         m_touch->processUp(id, 0);
                         waylandServer()->simulateUserActivity();
@@ -1848,6 +1868,8 @@ void InputRedirection::setupLibInput()
 
         conn->setInputConfig(kwinApp()->inputConfig());
         conn->updateLEDs(m_keyboard->xkb()->leds());
+        waylandServer()->updateKeyState(m_keyboard->xkb()->leds());
+        connect(m_keyboard, &KeyboardInputRedirection::ledsChanged, waylandServer(), &WaylandServer::updateKeyState);
         connect(m_keyboard, &KeyboardInputRedirection::ledsChanged, conn, &LibInput::Connection::updateLEDs);
         connect(conn, &LibInput::Connection::eventsRead, this,
             [this] {
@@ -2018,9 +2040,9 @@ void InputRedirection::processPointerButton(uint32_t button, InputRedirection::P
     m_pointer->processButton(button, state, time);
 }
 
-void InputRedirection::processPointerAxis(InputRedirection::PointerAxis axis, qreal delta, uint32_t time)
+void InputRedirection::processPointerAxis(InputRedirection::PointerAxis axis, qreal delta, qint32 discreteDelta, PointerAxisSource source, uint32_t time)
 {
-    m_pointer->processAxis(axis, delta, time);
+    m_pointer->processAxis(axis, delta, discreteDelta, source, time);
 }
 
 void InputRedirection::processKeyboardKey(uint32_t key, InputRedirection::KeyboardKeyState state, uint32_t time)
@@ -2118,7 +2140,7 @@ Toplevel *InputRedirection::findManagedToplevel(const QPoint &pos)
             continue;
         }
         if (AbstractClient *c = dynamic_cast<AbstractClient*>(t)) {
-            if (!c->isOnCurrentActivity() || !c->isOnCurrentDesktop() || c->isMinimized() || !c->isCurrentTab() || c->isHiddenInternal()) {
+            if (!c->isOnCurrentActivity() || !c->isOnCurrentDesktop() || c->isMinimized() || c->isHiddenInternal()) {
                 continue;
             }
         }
@@ -2229,11 +2251,14 @@ void InputDeviceHandler::init()
 
 bool InputDeviceHandler::setAt(Toplevel *toplevel)
 {
-    if (m_at == toplevel) {
+    if (m_at.at == toplevel) {
         return false;
     }
-    auto old = m_at;
-    m_at = toplevel;
+    auto old = m_at.at;
+    disconnect(m_at.surfaceCreatedConnection);
+    m_at.surfaceCreatedConnection = QMetaObject::Connection();
+
+    m_at.at = toplevel;
     emit atChanged(old, toplevel);
     return true;
 }
@@ -2261,7 +2286,19 @@ void InputDeviceHandler::setInternalWindow(QWindow *window)
 void InputDeviceHandler::updateFocus()
 {
     auto oldFocus = m_focus.focus;
-    m_focus.focus = m_at;
+
+    if (m_at.at && !m_at.at->surface()) {
+        // The surface has not yet been created (special XWayland case).
+        // Therefore listen for its creation.
+        if (!m_at.surfaceCreatedConnection) {
+            m_at.surfaceCreatedConnection = connect(m_at.at, &Toplevel::surfaceChanged,
+                                                    this, &InputDeviceHandler::update);
+        }
+        m_focus.focus = nullptr;
+    } else {
+        m_focus.focus = m_at.at;
+    }
+
     focusUpdate(oldFocus, m_focus.focus);
 }
 
@@ -2270,7 +2307,7 @@ bool InputDeviceHandler::updateDecoration()
     const auto oldDeco = m_focus.decoration;
     m_focus.decoration = nullptr;
 
-    auto *ac = qobject_cast<AbstractClient*>(m_at);
+    auto *ac = qobject_cast<AbstractClient*>(m_at.at);
     if (ac && ac->decoratedClient()) {
         const QRect clientRect = QRect(ac->clientPos(), ac->clientSize()).translated(ac->pos());
         if (!clientRect.contains(position().toPoint())) {
@@ -2338,7 +2375,7 @@ void InputDeviceHandler::update()
     }
     updateInternalWindow(nullptr);
 
-    if (m_focus.focus != m_at) {
+    if (m_focus.focus != m_at.at) {
         // focus change
         updateDecoration();
         updateFocus();
