@@ -36,7 +36,7 @@ class ButtonsModel : public QAbstractListModel
 public:
     explicit ButtonsModel(const QVector< DecorationButtonType > &buttons, QObject *parent = 0);
     explicit ButtonsModel(QObject *parent = nullptr);
-    virtual ~ButtonsModel();
+    ~ButtonsModel() override;
     QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
     int rowCount(const QModelIndex& parent = QModelIndex()) const override;
     QHash< int, QByteArray > roleNames() const override;
