@@ -60,7 +60,7 @@ std::unique_ptr<DecoratedClientPrivate> PreviewBridge::createClient(DecoratedCli
 {
     auto ptr = std::unique_ptr<PreviewClient>(new PreviewClient(client, decoration));
     m_lastCreatedClient = ptr.get();
-    return std::move(ptr);
+    return ptr;
 }
 
 void PreviewBridge::update(Decoration *decoration, const QRect &geometry)
@@ -78,7 +78,7 @@ std::unique_ptr<DecorationSettingsPrivate> PreviewBridge::settings(DecorationSet
 {
     auto ptr = std::unique_ptr<PreviewSettings>(new PreviewSettings(parent));
     m_lastCreatedSettings = ptr.get();
-    return std::move(ptr);
+    return ptr;
 }
 
 void PreviewBridge::registerPreviewItem(PreviewItem *item)
