@@ -31,7 +31,6 @@
 #include <kactivities/consumer.h>
 #endif
 
-#include <assert.h>
 #include <kmessagebox.h>
 #include <QTabWidget>
 #include <QTimer>
@@ -682,7 +681,7 @@ STRING_MATCH_COMBO(machine)
 
 void RulesWidget::detectClicked()
 {
-    assert(detect_dlg == nullptr);
+    Q_ASSERT(detect_dlg == nullptr);
     detect_dlg = new DetectDialog;
     connect(detect_dlg, SIGNAL(detectionDone(bool)), this, SLOT(detected(bool)));
     detect_dlg->detect(Ui::RulesWidgetBase::detection_delay->value());
