@@ -79,8 +79,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 */
 
-#include <assert.h>
-
 #include "utils.h"
 #include "client.h"
 #include "focuschain.h"
@@ -142,7 +140,7 @@ void Workspace::updateStackingOrder(bool propagate_new_clients)
  * the regular propagateClients function in that it completely ignores managed clients and everything
  * else and also does not update the NETWM property.
  * Called from Effects::destroyInputWindow so far.
- **/
+ */
 void Workspace::stackScreenEdgesUnderOverrideRedirect()
 {
     if (!rootInfo()) {
@@ -154,7 +152,7 @@ void Workspace::stackScreenEdgesUnderOverrideRedirect()
 /**
  * Propagates the managed clients to the world.
  * Called ONLY from updateStackingOrder().
- **/
+ */
 void Workspace::propagateClients(bool propagate_new_clients)
 {
     if (!rootInfo()) {
@@ -201,7 +199,7 @@ void Workspace::propagateClients(bool propagate_new_clients)
     }
     // TODO isn't it too inefficient to restack always all clients?
     // TODO don't restack not visible windows?
-    assert(newWindowStack.at(0) == rootInfo()->supportWindow());
+    Q_ASSERT(newWindowStack.at(0) == rootInfo()->supportWindow());
     Xcb::restackWindows(newWindowStack);
 
     int pos = 0;
@@ -241,7 +239,7 @@ void Workspace::propagateClients(bool propagate_new_clients)
  * Returns topmost visible client. Windows on the dock, the desktop
  * or of any other special kind are excluded. Also if the window
  * doesn't accept focus it's excluded.
- **/
+ */
 // TODO misleading name for this method, too many slightly different ways to use it
 AbstractClient* Workspace::topClientOnDesktop(int desktop, int screen, bool unconstrained, bool only_normal) const
 {
@@ -450,7 +448,7 @@ void Workspace::lowerClientRequest(KWin::AbstractClient *c)
 
 void Workspace::restack(AbstractClient* c, AbstractClient* under, bool force)
 {
-    assert(unconstrained_stacking_order.contains(under));
+    Q_ASSERT(unconstrained_stacking_order.contains(under));
     if (!force && !AbstractClient::belongToSameApplication(under, c)) {
          // put in the stacking order below _all_ windows belonging to the active application
         for (int i = 0; i < unconstrained_stacking_order.size(); ++i) {
@@ -466,7 +464,7 @@ void Workspace::restack(AbstractClient* c, AbstractClient* under, bool force)
         unconstrained_stacking_order.insert(unconstrained_stacking_order.indexOf(under), c);
     }
 
-    assert(unconstrained_stacking_order.contains(c));
+    Q_ASSERT(unconstrained_stacking_order.contains(c));
     FocusChain::self()->moveAfterClient(c, under);
     updateStackingOrder();
 }
@@ -503,7 +501,7 @@ void Workspace::restoreSessionStackingOrder(Client* c)
 
 /**
  * Returns a stacking order based upon \a list that fulfills certain contained.
- **/
+ */
 ToplevelList Workspace::constrainedStackingOrder()
 {
     ToplevelList layer[ NumLayers ];
@@ -530,10 +528,9 @@ ToplevelList Workspace::constrainedStackingOrder()
         layer[ l ].append(*it);
     }
     ToplevelList stacking;
-    for (Layer lay = FirstLayer;
-            lay < NumLayers;
-            ++lay)
-        stacking += layer[ lay ];
+    for (int lay = FirstLayer; lay < NumLayers; ++lay) {
+        stacking += layer[lay];
+    }
     // now keep transients above their mainwindows
     // TODO this could(?) use some optimization
     for (int i = stacking.size() - 1; i >= 0;) {
@@ -856,16 +853,10 @@ void Client::restackWindow(xcb_window_t above, int detail, NET::RequestSource sr
 
 void Client::doSetKeepAbove()
 {
-    // Update states of all other windows in this group
-    if (tabGroup())
-        tabGroup()->updateStates(this, TabGroup::Layer);
 }
 
 void Client::doSetKeepBelow()
 {
-    // Update states of all other windows in this group
-    if (tabGroup())
-        tabGroup()->updateStates(this, TabGroup::Layer);
 }
 
 bool Client::belongsToDesktop() const
