@@ -29,18 +29,18 @@ class AbstractOutput;
 
 /**
  * @brief Implementation for backends with Outputs
- **/
+ */
 class KWIN_EXPORT OutputScreens : public Screens
 {
     Q_OBJECT
 public:
     OutputScreens(Platform *platform, QObject *parent = nullptr);
-    virtual ~OutputScreens();
+    ~OutputScreens() override;
 
     void init() override;
     QString name(int screen) const override;
-    bool isInternal(int screen) const;
-    QSizeF physicalSize(int screen) const;
+    bool isInternal(int screen) const override;
+    QSizeF physicalSize(int screen) const override;
     QRect geometry(int screen) const override;
     QSize size(int screen) const override;
     qreal scale(int screen) const override;
