@@ -48,7 +48,7 @@ class Decoration : public KDecoration2::Decoration
     Q_PROPERTY(KDecoration2::DecoratedClient* client READ clientPointer CONSTANT)
 public:
     explicit Decoration(QObject *parent = nullptr, const QVariantList &args = QVariantList());
-    virtual ~Decoration();
+    ~Decoration() override;
 
     void paint(QPainter *painter, const QRect &repaintRegion) override;
 
@@ -76,6 +76,7 @@ protected:
 private:
     void setupBorders(QQuickItem *item);
     void updateBorders();
+    void updateBuffer();
     QMouseEvent translatedMouseEvent(QMouseEvent *orig);
     QScopedPointer<QOpenGLFramebufferObject> m_fbo;
     QImage m_buffer;
