@@ -23,8 +23,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "drm_object_crtc.h"
 #include "drm_object_connector.h"
 
-#include <errno.h>
-
 #include "composite.h"
 #include "logind.h"
 #include "logging.h"
@@ -42,6 +40,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QMatrix4x4>
 #include <QCryptographicHash>
 #include <QPainter>
+// c++
+#include <cerrno>
 // drm
 #include <xf86drm.h>
 #include <xf86drmMode.h>
@@ -51,7 +51,7 @@ namespace KWin
 {
 
 DrmOutput::DrmOutput(DrmBackend *backend)
-    : AbstractOutput(backend)
+    : AbstractWaylandOutput(backend)
     , m_backend(backend)
 {
 }
@@ -59,13 +59,14 @@ DrmOutput::DrmOutput(DrmBackend *backend)
 DrmOutput::~DrmOutput()
 {
     Q_ASSERT(!m_pageFlipPending);
-    if (!m_deleted) {
-        teardown();
-    }
+    teardown();
 }
 
 void DrmOutput::teardown()
 {
+    if (m_deleted) {
+        return;
+    }
     m_deleted = true;
     hideCursor();
     m_crtc->blank();
@@ -180,7 +181,7 @@ void DrmOutput::moveCursor(const QPoint &globalPos)
 {
     const QMatrix4x4 hotspotMatrix = matrixDisplay(m_backend->softwareCursor().size());
 
-    QPoint p = globalPos-AbstractOutput::globalPos();
+    QPoint p = globalPos - AbstractWaylandOutput::globalPos();
     switch (orientation()) {
     case Qt::PrimaryOrientation:
     case Qt::LandscapeOrientation:
@@ -266,23 +267,8 @@ bool DrmOutput::init(drmModeConnector *connector)
         );
     }
 
-    QSize physicalSize = !m_edid.physicalSize.isEmpty() ? m_edid.physicalSize : QSize(connector->mmWidth, connector->mmHeight);
-    // the size might be completely borked. E.g. Samsung SyncMaster 2494HS reports 160x90 while in truth it's 520x292
-    // as this information is used to calculate DPI info, it's going to result in everything being huge
-    const QByteArray unknown = QByteArrayLiteral("unknown");
-    KConfigGroup group = kwinApp()->config()->group("EdidOverwrite").group(m_edid.eisaId.isEmpty() ? unknown : m_edid.eisaId)
-                                                       .group(m_edid.monitorName.isEmpty() ? unknown : m_edid.monitorName)
-                                                       .group(m_edid.serialNumber.isEmpty() ? unknown : m_edid.serialNumber);
-    if (group.hasKey("PhysicalSize")) {
-        const QSize overwriteSize = group.readEntry("PhysicalSize", physicalSize);
-        qCWarning(KWIN_DRM) << "Overwriting monitor physical size for" << m_edid.eisaId << "/" << m_edid.monitorName << "/" << m_edid.serialNumber << " from " << physicalSize << "to " << overwriteSize;
-        physicalSize = overwriteSize;
-    }
-    setRawPhysicalSize(physicalSize);
-
     initOutputDevice(connector);
-
-    setEnabled(true);
+    updateDpms(KWayland::Server::OutputInterface::DpmsMode::On);
     return true;
 }
 
@@ -290,31 +276,31 @@ void DrmOutput::initUuid()
 {
     QCryptographicHash hash(QCryptographicHash::Md5);
     hash.addData(QByteArray::number(m_conn->id()));
-    hash.addData(m_edid.eisaId);
-    hash.addData(m_edid.monitorName);
-    hash.addData(m_edid.serialNumber);
+    hash.addData(m_edid.eisaId());
+    hash.addData(m_edid.monitorName());
+    hash.addData(m_edid.serialNumber());
     m_uuid = hash.result().toHex().left(10);
 }
 
 void DrmOutput::initOutputDevice(drmModeConnector *connector)
 {
     QString manufacturer;
-    if (!m_edid.eisaId.isEmpty()) {
-        manufacturer = QString::fromLatin1(m_edid.eisaId);
+    if (!m_edid.eisaId().isEmpty()) {
+        manufacturer = QString::fromLatin1(m_edid.eisaId());
     }
 
     QString connectorName = s_connectorNames.value(connector->connector_type, QByteArrayLiteral("Unknown"));
     QString modelName;
 
-    if (!m_edid.monitorName.isEmpty()) {
-        QString m = QString::fromLatin1(m_edid.monitorName);
-        if (!m_edid.serialNumber.isEmpty()) {
+    if (!m_edid.monitorName().isEmpty()) {
+        QString m = QString::fromLatin1(m_edid.monitorName());
+        if (!m_edid.serialNumber().isEmpty()) {
             m.append('/');
-            m.append(QString::fromLatin1(m_edid.serialNumber));
+            m.append(QString::fromLatin1(m_edid.serialNumber()));
         }
         modelName = m;
-    } else if (!m_edid.serialNumber.isEmpty()) {
-        modelName = QString::fromLatin1(m_edid.serialNumber);
+    } else if (!m_edid.serialNumber().isEmpty()) {
+        modelName = QString::fromLatin1(m_edid.serialNumber());
     } else {
         modelName = i18n("unknown");
     }
@@ -343,7 +329,20 @@ void DrmOutput::initOutputDevice(drmModeConnector *connector)
         modes << mode;
     }
 
-    AbstractOutput::initWaylandOutputDevice(model, manufacturer, m_uuid, modes);
+    QSize physicalSize = !m_edid.physicalSize().isEmpty() ? m_edid.physicalSize() : QSize(connector->mmWidth, connector->mmHeight);
+    // the size might be completely borked. E.g. Samsung SyncMaster 2494HS reports 160x90 while in truth it's 520x292
+    // as this information is used to calculate DPI info, it's going to result in everything being huge
+    const QByteArray unknown = QByteArrayLiteral("unknown");
+    KConfigGroup group = kwinApp()->config()->group("EdidOverwrite").group(m_edid.eisaId().isEmpty() ? unknown : m_edid.eisaId())
+                                                       .group(m_edid.monitorName().isEmpty() ? unknown : m_edid.monitorName())
+                                                       .group(m_edid.serialNumber().isEmpty() ? unknown : m_edid.serialNumber());
+    if (group.hasKey("PhysicalSize")) {
+        const QSize overwriteSize = group.readEntry("PhysicalSize", physicalSize);
+        qCWarning(KWIN_DRM) << "Overwriting monitor physical size for" << m_edid.eisaId() << "/" << m_edid.monitorName() << "/" << m_edid.serialNumber() << " from " << physicalSize << "to " << overwriteSize;
+        physicalSize = overwriteSize;
+    }
+
+    initInterfaces(model, manufacturer, m_uuid, physicalSize, modes);
 }
 
 bool DrmOutput::isCurrentMode(const drmModeModeInfo *mode) const
@@ -365,133 +364,6 @@ bool DrmOutput::isCurrentMode(const drmModeModeInfo *mode) const
         && qstrcmp(mode->name, m_mode.name) == 0;
 }
 
-static bool verifyEdidHeader(drmModePropertyBlobPtr edid)
-{
-    const uint8_t *data = reinterpret_cast<uint8_t*>(edid->data);
-    if (data[0] != 0x00) {
-        return false;
-    }
-    for (int i = 1; i < 7; ++i) {
-        if (data[i] != 0xFF) {
-            return false;
-        }
-    }
-    if (data[7] != 0x00) {
-        return false;
-    }
-    return true;
-}
-
-static QByteArray extractEisaId(drmModePropertyBlobPtr edid)
-{
-    /*
-     * From EDID standard section 3.4:
-     * The ID Manufacturer Name field, shown in Table 3.5, contains a 2-byte representation of the monitor's
-     * manufacturer. This is the same as the EISA ID. It is based on compressed ASCII, “0001=A” ... “11010=Z”.
-     *
-     * The table:
-     * | Byte |        Bit                    |
-     * |      | 7 | 6 | 5 | 4 | 3 | 2 | 1 | 0 |
-     * ----------------------------------------
-     * |  1   | 0)| (4| 3 | 2 | 1 | 0)| (4| 3 |
-     * |      | * |    Character 1    | Char 2|
-     * ----------------------------------------
-     * |  2   | 2 | 1 | 0)| (4| 3 | 2 | 1 | 0)|
-     * |      | Character2|      Character 3  |
-     * ----------------------------------------
-     **/
-    const uint8_t *data = reinterpret_cast<uint8_t*>(edid->data);
-    static const uint offset = 0x8;
-    char id[4];
-    if (data[offset] >> 7) {
-        // bit at position 7 is not a 0
-        return QByteArray();
-    }
-    // shift two bits to right, and with 7 right most bits
-    id[0] = 'A' + ((data[offset] >> 2) & 0x1f) -1;
-    // for first byte: take last two bits and shift them 3 to left (000xx000)
-    // for second byte: shift 5 bits to right and take 3 right most bits (00000xxx)
-    // or both together
-    id[1] = 'A' + (((data[offset] & 0x3) << 3) | ((data[offset + 1] >> 5) & 0x7)) - 1;
-    // take five right most bits
-    id[2] = 'A' + (data[offset + 1] & 0x1f) - 1;
-    id[3] = '\0';
-    return QByteArray(id);
-}
-
-static void extractMonitorDescriptorDescription(drmModePropertyBlobPtr blob, DrmOutput::Edid &edid)
-{
-    // see section 3.10.3
-    const uint8_t *data = reinterpret_cast<uint8_t*>(blob->data);
-    static const uint offset = 0x36;
-    static const uint blockLength = 18;
-    for (int i = 0; i < 5; ++i) {
-        const uint co = offset + i * blockLength;
-        // Flag = 0000h when block used as descriptor
-        if (data[co] != 0) {
-            continue;
-        }
-        if (data[co + 1] != 0) {
-            continue;
-        }
-        // Reserved = 00h when block used as descriptor
-        if (data[co + 2] != 0) {
-            continue;
-        }
-        /*
-         * FFh: Monitor Serial Number - Stored as ASCII, code page # 437, ≤ 13 bytes.
-         * FEh: ASCII String - Stored as ASCII, code page # 437, ≤ 13 bytes.
-         * FDh: Monitor range limits, binary coded
-         * FCh: Monitor name, stored as ASCII, code page # 437
-         * FBh: Descriptor contains additional color point data
-         * FAh: Descriptor contains additional Standard Timing Identifications
-         * F9h - 11h: Currently undefined
-         * 10h: Dummy descriptor, used to indicate that the descriptor space is unused
-         * 0Fh - 00h: Descriptor defined by manufacturer.
-         */
-        if (data[co + 3] == 0xfc && edid.monitorName.isEmpty()) {
-            edid.monitorName = QByteArray((const char *)(&data[co + 5]), 12).trimmed();
-        }
-        if (data[co + 3] == 0xfe) {
-            const QByteArray id = QByteArray((const char *)(&data[co + 5]), 12).trimmed();
-            if (!id.isEmpty()) {
-                edid.eisaId = id;
-            }
-        }
-        if (data[co + 3] == 0xff) {
-            edid.serialNumber = QByteArray((const char *)(&data[co + 5]), 12).trimmed();
-        }
-    }
-}
-
-static QByteArray extractSerialNumber(drmModePropertyBlobPtr edid)
-{
-    // see section 3.4
-    const uint8_t *data = reinterpret_cast<uint8_t*>(edid->data);
-    static const uint offset = 0x0C;
-    /*
-     * The ID serial number is a 32-bit serial number used to differentiate between individual instances of the same model
-     * of monitor. Its use is optional. When used, the bit order for this field follows that shown in Table 3.6. The EDID
-     * structure Version 1 Revision 1 and later offer a way to represent the serial number of the monitor as an ASCII string
-     * in a separate descriptor block.
-     */
-    uint32_t serialNumber = 0;
-    serialNumber  = (uint32_t) data[offset + 0];
-    serialNumber |= (uint32_t) data[offset + 1] << 8;
-    serialNumber |= (uint32_t) data[offset + 2] << 16;
-    serialNumber |= (uint32_t) data[offset + 3] << 24;
-    if (serialNumber == 0) {
-        return QByteArray();
-    }
-    return QByteArray::number(serialNumber);
-}
-
-static QSize extractPhysicalSize(drmModePropertyBlobPtr edid)
-{
-    const uint8_t *data = reinterpret_cast<uint8_t*>(edid->data);
-    return QSize(data[0x15], data[0x16]) * 10;
-}
-
 void DrmOutput::initEdid(drmModeConnector *connector)
 {
     DrmScopedPointer<drmModePropertyBlobRes> edid;
@@ -508,20 +380,10 @@ void DrmOutput::initEdid(drmModeConnector *connector)
         return;
     }
 
-    // for documentation see: http://read.pudn.com/downloads110/ebook/456020/E-EDID%20Standard.pdf
-    if (edid->length < 128) {
-        return;
+    m_edid = Edid(edid->data, edid->length);
+    if (!m_edid.isValid()) {
+        qCWarning(KWIN_DRM, "Couldn't parse EDID for connector with id %d", m_conn->id());
     }
-    if (!verifyEdidHeader(edid.data())) {
-        return;
-    }
-    m_edid.eisaId = extractEisaId(edid.data());
-    m_edid.serialNumber = extractSerialNumber(edid.data());
-
-    // parse monitor descriptor description
-    extractMonitorDescriptorDescription(edid.data(), m_edid);
-
-    m_edid.physicalSize = extractPhysicalSize(edid.data());
 }
 
 bool DrmOutput::initPrimaryPlane()
@@ -608,6 +470,56 @@ void DrmOutput::initDpms(drmModeConnector *connector)
     }
 }
 
+void DrmOutput::updateEnablement(bool enable)
+{
+    if (enable) {
+        m_dpmsModePending = DpmsMode::On;
+        if (m_backend->atomicModeSetting()) {
+            atomicEnable();
+        } else {
+            if (dpmsLegacyApply()) {
+                m_backend->enableOutput(this, true);
+            }
+        }
+
+    } else {
+        m_dpmsModePending = DpmsMode::Off;
+        if (m_backend->atomicModeSetting()) {
+            atomicDisable();
+        } else {
+            if (dpmsLegacyApply()) {
+                m_backend->enableOutput(this, false);
+            }
+        }
+    }
+}
+
+void DrmOutput::atomicEnable()
+{
+    m_modesetRequested = true;
+
+    if (m_atomicOffPending) {
+        Q_ASSERT(m_pageFlipPending);
+        m_atomicOffPending = false;
+    }
+    m_backend->enableOutput(this, true);
+
+    if (Compositor *compositor = Compositor::self()) {
+        compositor->addRepaintFull();
+    }
+}
+
+void DrmOutput::atomicDisable()
+{
+    m_modesetRequested = true;
+
+    m_backend->enableOutput(this, false);
+    m_atomicOffPending = true;
+    if (!m_pageFlipPending) {
+        dpmsAtomicOff();
+    }
+}
+
 static DrmOutput::DpmsMode fromWaylandDpmsMode(KWayland::Server::OutputInterface::DpmsMode wlMode)
 {
     using namespace KWayland::Server;
@@ -644,11 +556,12 @@ static KWayland::Server::OutputInterface::DpmsMode toWaylandDpmsMode(DrmOutput::
 
 void DrmOutput::updateDpms(KWayland::Server::OutputInterface::DpmsMode mode)
 {
-    if (m_dpms.isNull()) {
+    if (m_dpms.isNull() || !isEnabled()) {
         return;
     }
 
     const auto drmMode = fromWaylandDpmsMode(mode);
+
     if (drmMode == m_dpmsModePending) {
         qCDebug(KWIN_DRM) << "New DPMS mode equals old mode. DPMS unchanged.";
         return;
@@ -659,41 +572,30 @@ void DrmOutput::updateDpms(KWayland::Server::OutputInterface::DpmsMode mode)
     if (m_backend->atomicModeSetting()) {
         m_modesetRequested = true;
         if (drmMode == DpmsMode::On) {
-            if (m_pageFlipPending) {
-                m_pageFlipPending = false;
-                Compositor::self()->bufferSwapComplete();
+            if (m_atomicOffPending) {
+                Q_ASSERT(m_pageFlipPending);
+                m_atomicOffPending = false;
             }
-            dpmsOnHandler();
+            dpmsFinishOn();
         } else {
-            m_dpmsAtomicOffPending = true;
+            m_atomicOffPending = true;
             if (!m_pageFlipPending) {
                 dpmsAtomicOff();
             }
         }
     } else {
-        if (drmModeConnectorSetProperty(m_backend->fd(), m_conn->id(), m_dpms->prop_id, uint64_t(drmMode)) < 0) {
-            m_dpmsModePending = m_dpmsMode;
-            qCWarning(KWIN_DRM) << "Setting DPMS failed";
-            return;
-        }
-        if (drmMode == DpmsMode::On) {
-            dpmsOnHandler();
-        } else {
-            dpmsOffHandler();
-        }
-        m_dpmsMode = m_dpmsModePending;
+       dpmsLegacyApply();
     }
 }
 
-void DrmOutput::dpmsOnHandler()
+void DrmOutput::dpmsFinishOn()
 {
     qCDebug(KWIN_DRM) << "DPMS mode set for output" << m_crtc->id() << "to On.";
 
     auto wlOutput = waylandOutput();
     if (wlOutput) {
-        wlOutput->setDpmsMode(toWaylandDpmsMode(m_dpmsModePending));
+        wlOutput->setDpmsMode(toWaylandDpmsMode(DpmsMode::On));
     }
-    emit dpmsChanged();
 
     m_backend->checkOutputsAreOn();
     if (!m_backend->atomicModeSetting()) {
@@ -704,17 +606,31 @@ void DrmOutput::dpmsOnHandler()
     }
 }
 
-void DrmOutput::dpmsOffHandler()
+void DrmOutput::dpmsFinishOff()
 {
     qCDebug(KWIN_DRM) << "DPMS mode set for output" << m_crtc->id() << "to Off.";
 
-    auto wlOutput = waylandOutput();
-    if (wlOutput) {
-        wlOutput->setDpmsMode(toWaylandDpmsMode(m_dpmsModePending));
+    if (isEnabled()) {
+        waylandOutput()->setDpmsMode(toWaylandDpmsMode(m_dpmsModePending));
+        m_backend->createDpmsFilter();
     }
-    emit dpmsChanged();
+}
 
-    m_backend->outputWentOff();
+bool DrmOutput::dpmsLegacyApply()
+{
+    if (drmModeConnectorSetProperty(m_backend->fd(), m_conn->id(),
+                                    m_dpms->prop_id, uint64_t(m_dpmsModePending)) < 0) {
+        m_dpmsModePending = m_dpmsMode;
+        qCWarning(KWIN_DRM) << "Setting DPMS failed";
+        return false;
+    }
+    if (m_dpmsModePending == DpmsMode::On) {
+        dpmsFinishOn();
+    } else {
+        dpmsFinishOff();
+    }
+    m_dpmsMode = m_dpmsModePending;
+    return true;
 }
 
 void DrmOutput::transform(KWayland::Server::OutputDeviceInterface::Transform transform)
@@ -812,19 +728,15 @@ void DrmOutput::updateMode(int modeIndex)
     setWaylandMode();
 }
 
-QSize DrmOutput::pixelSize() const
-{
-    return orientateSize(QSize(m_mode.hdisplay, m_mode.vdisplay));
-}
-
 void DrmOutput::setWaylandMode()
 {
-    AbstractOutput::setWaylandMode(QSize(m_mode.hdisplay, m_mode.vdisplay),
-                                   refreshRateForMode(&m_mode));
+    AbstractWaylandOutput::setWaylandMode(QSize(m_mode.hdisplay, m_mode.vdisplay),
+                                          refreshRateForMode(&m_mode));
 }
 
 void DrmOutput::pageFlipped()
 {
+    Q_ASSERT(m_pageFlipPending);
     m_pageFlipPending = false;
     if (m_deleted) {
         deleteLater();
@@ -872,10 +784,17 @@ void DrmOutput::pageFlipped()
         }
         m_crtc->flipBuffer();
     }
+
+    if (m_atomicOffPending) {
+        dpmsAtomicOff();
+    }
 }
 
 bool DrmOutput::present(DrmBuffer *buffer)
 {
+    if (m_dpmsModePending != DpmsMode::On) {
+        return false;
+    }
     if (m_backend->atomicModeSetting()) {
         return presentAtomically(buffer);
     } else {
@@ -885,7 +804,7 @@ bool DrmOutput::present(DrmBuffer *buffer)
 
 bool DrmOutput::dpmsAtomicOff()
 {
-    m_dpmsAtomicOffPending = false;
+    m_atomicOffPending = false;
 
     // TODO: With multiple planes: deactivate all of them here
     delete m_primaryPlane->next();
@@ -901,10 +820,9 @@ bool DrmOutput::dpmsAtomicOff()
         return false;
     }
     m_nextPlanesFlipList.clear();
-    dpmsOffHandler();
+    dpmsFinishOff();
 
     return true;
-
 }
 
 bool DrmOutput::presentAtomically(DrmBuffer *buffer)
@@ -982,9 +900,6 @@ bool DrmOutput::presentLegacy(DrmBuffer *buffer)
         m_crtc->setNext(buffer);
         return false;
     }
-    if (m_dpmsMode != DpmsMode::On) {
-        return false;
-    }
 
     // Do we need to set a new mode first?
     if (!m_crtc->current() || m_crtc->current()->needsModeChange(buffer)) {
@@ -1028,7 +943,7 @@ bool DrmOutput::doAtomicCommit(AtomicCommitMode mode)
             qCWarning(KWIN_DRM) << "Setting DPMS failed";
             m_dpmsModePending = m_dpmsMode;
             if (m_dpmsMode != DpmsMode::On) {
-                dpmsOffHandler();
+                dpmsFinishOff();
             }
         }
 
@@ -1201,12 +1116,12 @@ void DrmOutput::automaticRotation()
     emit screens()->changed();
 }
 
-int DrmOutput::getGammaRampSize() const
+int DrmOutput::gammaRampSize() const
 {
-    return m_crtc->getGammaRampSize();
+    return m_crtc->gammaRampSize();
 }
 
-bool DrmOutput::setGammaRamp(const ColorCorrect::GammaRamp &gamma)
+bool DrmOutput::setGammaRamp(const GammaRamp &gamma)
 {
     return m_crtc->setGammaRamp(gamma);
 }
