@@ -20,7 +20,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef KWIN_HWCOMPOSER_BACKEND_H
 #define KWIN_HWCOMPOSER_BACKEND_H
 #include "platform.h"
-#include "abstract_output.h"
+#include "abstract_wayland_output.h"
 #include "input.h"
 
 #include <QElapsedTimer>
@@ -47,7 +47,7 @@ namespace KWin
 class HwcomposerWindow;
 class BacklightInputEventFilter;
 
-class HwcomposerOutput : public AbstractOutput
+class HwcomposerOutput : public AbstractWaylandOutput
 {
     Q_OBJECT
 public:
@@ -150,9 +150,9 @@ public:
     bool pointerEvent(QMouseEvent *event, quint32 nativeButton) override;
     bool wheelEvent(QWheelEvent *event) override;
     bool keyEvent(QKeyEvent *event) override;
-    bool touchDown(quint32 id, const QPointF &pos, quint32 time) override;
-    bool touchMotion(quint32 id, const QPointF &pos, quint32 time) override;
-    bool touchUp(quint32 id, quint32 time) override;
+    bool touchDown(qint32 id, const QPointF &pos, quint32 time) override;
+    bool touchMotion(qint32 id, const QPointF &pos, quint32 time) override;
+    bool touchUp(qint32 id, quint32 time) override;
 
 private:
     void toggleBacklight();
