@@ -53,14 +53,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <array>
 #include <cmath>
+#include <cstddef>
 #include <unistd.h>
-#include <stddef.h>
 
-#include <qpainter.h>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDBusInterface>
 #include <QGraphicsScale>
+#include <QPainter>
 #include <QStringList>
 #include <QVector2D>
 #include <QVector4D>
@@ -90,7 +90,7 @@ extern int currentRefreshRate();
 /**
  * SyncObject represents a fence used to synchronize operations in
  * the kwin command stream with operations in the X command stream.
- **/
+ */
 class SyncObject
 {
 public:
@@ -149,7 +149,7 @@ SyncObject::~SyncObject()
 
 void SyncObject::trigger()
 {
-    assert(m_state == Ready || m_state == Resetting);
+    Q_ASSERT(m_state == Ready || m_state == Resetting);
 
     // Finish resetting the fence if necessary
     if (m_state == Resetting)
@@ -176,7 +176,7 @@ bool SyncObject::finish()
     // Note: It is possible that we never inserted a wait for the fence.
     //       This can happen if we ended up not rendering the damaged
     //       window because it is fully occluded.
-    assert(m_state == TriggerSent || m_state == Waiting);
+    Q_ASSERT(m_state == TriggerSent || m_state == Waiting);
 
     // Check if the fence is signaled
     GLint value;
@@ -205,7 +205,7 @@ bool SyncObject::finish()
 
 void SyncObject::reset()
 {
-    assert(m_state == Done);
+    Q_ASSERT(m_state == Done);
 
     xcb_connection_t * const c = connection();
 
@@ -223,7 +223,7 @@ void SyncObject::reset()
 
 void SyncObject::finishResetting()
 {
-    assert(m_state == Resetting);
+    Q_ASSERT(m_state == Resetting);
     free(xcb_get_input_focus_reply(connection(), m_reset_cookie, nullptr));
     m_state = Ready;
 }
@@ -237,7 +237,7 @@ void SyncObject::finishResetting()
 /**
  * SyncManager manages a set of fences used for explicit synchronization
  * with the X command stream.
- **/
+ */
 class SyncManager
 {
 public:
@@ -468,7 +468,7 @@ void SceneOpenGL::initDebugOutput()
     if (have_KHR_debug)
         glEnable(GL_DEBUG_OUTPUT);
 
-#ifndef NDEBUG
+#if !defined(QT_NO_DEBUG)
     // Enable all debug messages
     glDebugMessageControl(GL_DONT_CARE, GL_DONT_CARE, GL_DONT_CARE, 0, nullptr, GL_TRUE);
 #else
@@ -519,7 +519,7 @@ SceneOpenGL *SceneOpenGL::createScene(QObject *parent)
     return scene;
 }
 
-OverlayWindow *SceneOpenGL::overlayWindow()
+OverlayWindow *SceneOpenGL::overlayWindow() const
 {
     return m_backend->overlayWindow();
 }
@@ -596,7 +596,7 @@ void SceneOpenGL::insertWait()
 /**
  * Render cursor texture in case hardware cursor is disabled.
  * Useful for screen recording apps or backends that can't do planes.
- **/
+ */
 void SceneOpenGL2::paintCursor()
 {
     // don't paint if we use hardware cursor or the cursor is hidden
@@ -823,11 +823,15 @@ SceneOpenGLTexture *SceneOpenGL::createTexture()
 }
 
 bool SceneOpenGL::viewportLimitsMatched(const QSize &size) const {
+    if (kwinApp()->operationMode() != Application::OperationModeX11) {
+        // TODO: On Wayland we can't suspend. Find a solution that works here as well!
+        return true;
+    }
     GLint limit[2];
     glGetIntegerv(GL_MAX_VIEWPORT_DIMS, limit);
     if (limit[0] < size.width() || limit[1] < size.height()) {
-        QMetaObject::invokeMethod(Compositor::self(), "suspend",
-                                  Qt::QueuedConnection, Q_ARG(Compositor::SuspendReason, Compositor::AllReasonSuspend));
+        QMetaObject::invokeMethod(static_cast<X11Compositor*>(Compositor::self()), "suspend",
+                                  Qt::QueuedConnection, Q_ARG(X11Compositor::SuspendReason, X11Compositor::AllReasonSuspend));
         return false;
     }
     return true;
@@ -1165,13 +1169,18 @@ bool SceneOpenGL::Window::beginRenderWindow(int mask, const QRegion &region, Win
     }
 
     // Update the texture filter
-    if (options->glSmoothScale() != 0 &&
-        (mask & (PAINT_WINDOW_TRANSFORMED | PAINT_SCREEN_TRANSFORMED)))
+    if (waylandServer()) {
         filter = ImageFilterGood;
-    else
-        filter = ImageFilterFast;
+        s_frameTexture->setFilter(GL_LINEAR);
+    } else {
+        if (options->glSmoothScale() != 0 &&
+            (mask & (PAINT_WINDOW_TRANSFORMED | PAINT_SCREEN_TRANSFORMED)))
+            filter = ImageFilterGood;
+        else
+            filter = ImageFilterFast;
 
-    s_frameTexture->setFilter(filter == ImageFilterGood ? GL_LINEAR : GL_NEAREST);
+        s_frameTexture->setFilter(filter == ImageFilterGood ? GL_LINEAR : GL_NEAREST);
+    }
 
     const GLVertexAttrib attribs[] = {
         { VA_Position, 2, GL_FLOAT, offsetof(GLVertex2D, position) },
@@ -1369,8 +1378,18 @@ void SceneOpenGL2Window::performPaint(int mask, QRegion region, WindowPaintData
 
     shader->setUniform(GLShader::Saturation, data.saturation());
 
-    const GLenum filter = (mask & (Effect::PAINT_WINDOW_TRANSFORMED | Effect::PAINT_SCREEN_TRANSFORMED))
-                           && options->glSmoothScale() != 0 ? GL_LINEAR : GL_NEAREST;
+    GLenum filter;
+    if (waylandServer()) {
+        filter = GL_LINEAR;
+    } else {
+        const bool isTransformed = mask & (Effect::PAINT_WINDOW_TRANSFORMED |
+                                           Effect::PAINT_SCREEN_TRANSFORMED);
+        if (isTransformed && options->glSmoothScale() != 0) {
+            filter = GL_LINEAR;
+        } else {
+            filter = GL_NEAREST;
+        }
+    }
 
     WindowQuadList quads[LeafCount];
 
