@@ -43,7 +43,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QDebug>
 #include <QPainter>
-#include <qmath.h>
+#include <QtMath>
 
 namespace KWin
 {
@@ -494,11 +494,16 @@ void SceneXrender::Window::performPaint(int mask, QRegion region, WindowPaintDat
         xform.matrix22 = DOUBLE_TO_FIXED(1.0 / yscale);
 
         // transform the shape for clipping in paintTransformedScreen()
-        QVector<QRect> rects = transformed_shape.rects();
-        for (int i = 0; i < rects.count(); ++i) {
-            QRect& r = rects[ i ];
-            r.setRect(qRound(r.x() * xscale), qRound(r.y() * yscale),
-                      qRound(r.width() * xscale), qRound(r.height() * yscale));
+        QVector<QRect> rects;
+        rects.reserve(transformed_shape.rectCount());
+        for (const QRect &rect : transformed_shape) {
+            const QRect transformedRect(
+                qRound(rect.x() * xscale),
+                qRound(rect.y() * yscale),
+                qRound(rect.width() * xscale),
+                qRound(rect.height() * yscale)
+            );
+            rects.append(transformedRect);
         }
         transformed_shape.setRects(rects.constData(), rects.count());
     }
@@ -1233,7 +1238,7 @@ void SceneXRenderDecorationRenderer::render()
         Q_ASSERT(image.devicePixelRatio() == 1);
         xcb_put_image(c, XCB_IMAGE_FORMAT_Z_PIXMAP, m_pixmaps[index], m_gc,
                       image.width(), image.height(), geo.x() - offset.x(), geo.y() - offset.y(), 0, 32,
-                      image.byteCount(), image.constBits());
+                      image.sizeInBytes(), image.constBits());
     };
     const QRect geometry = scheduled.boundingRect();
     renderPart(left.intersected(geometry),   left.topLeft(),   int(DecorationPart::Left));
