@@ -224,7 +224,7 @@ void Scene::paintGenericScreen(int orig_mask, ScreenPaintData)
         data.quads = w->buildQuads();
         // preparation step
         effects->prePaintWindow(effectWindow(w), data, time_diff);
-#ifndef NDEBUG
+#if !defined(QT_NO_DEBUG)
         if (data.quads.isTransformed()) {
             qFatal("Pre-paint calls are not allowed to transform quads!");
         }
@@ -248,7 +248,7 @@ void Scene::paintGenericScreen(int orig_mask, ScreenPaintData)
 // to reduce painting and improve performance.
 void Scene::paintSimpleScreen(int orig_mask, QRegion region)
 {
-    assert((orig_mask & (PAINT_SCREEN_TRANSFORMED
+    Q_ASSERT((orig_mask & (PAINT_SCREEN_TRANSFORMED
                          | PAINT_SCREEN_WITH_TRANSFORMED_WINDOWS)) == 0);
     QVector<Phase2Data> phase2data;
     phase2data.reserve(stacking_order.size());
@@ -300,7 +300,7 @@ void Scene::paintSimpleScreen(int orig_mask, QRegion region)
         data.quads = w->buildQuads();
         // preparation step
         effects->prePaintWindow(effectWindow(w), data, time_diff);
-#ifndef NDEBUG
+#if !defined(QT_NO_DEBUG)
         if (data.quads.isTransformed()) {
             qFatal("Pre-paint calls are not allowed to transform quads!");
         }
@@ -392,7 +392,7 @@ void Scene::paintSimpleScreen(int orig_mask, QRegion region)
 
 void Scene::addToplevel(Toplevel *c)
 {
-    assert(!m_windows.contains(c));
+    Q_ASSERT(!m_windows.contains(c));
     Scene::Window *w = createWindow(c);
     m_windows[ c ] = w;
     connect(c, SIGNAL(geometryShapeChanged(KWin::Toplevel*,QRect)), SLOT(windowGeometryShapeChanged(KWin::Toplevel*)));
@@ -401,7 +401,11 @@ void Scene::addToplevel(Toplevel *c)
     if (c->surface()) {
         connect(c->surface(), &KWayland::Server::SurfaceInterface::scaleChanged, this, std::bind(&Scene::windowGeometryShapeChanged, this, c));
     }
-    connect(c, &Toplevel::screenScaleChanged, std::bind(&Scene::windowGeometryShapeChanged, this, c));
+    connect(c, &Toplevel::screenScaleChanged, this,
+        [this, c] {
+            windowGeometryShapeChanged(c);
+        }
+    );
     c->effectWindow()->setSceneWindow(w);
     c->getShadow();
     w->updateShadow(c->shadow());
@@ -447,7 +451,7 @@ void Scene::createStackingOrder(ToplevelList toplevels)
 {
     // TODO: cache the stacking_order in case it has not changed
     foreach (Toplevel *c, toplevels) {
-        assert(m_windows.contains(c));
+        Q_ASSERT(m_windows.contains(c));
         stacking_order.append(m_windows[ c ]);
     }
 }
@@ -509,7 +513,7 @@ static void adjustClipRegion(AbstractThumbnailItem *item, QRegion &clippingRegio
 void Scene::paintWindowThumbnails(Scene::Window *w, QRegion region, qreal opacity, qreal brightness, qreal saturation)
 {
     EffectWindowImpl *wImpl = static_cast<EffectWindowImpl*>(effectWindow(w));
-    for (QHash<WindowThumbnailItem*, QWeakPointer<EffectWindowImpl> >::const_iterator it = wImpl->thumbnails().constBegin();
+    for (QHash<WindowThumbnailItem*, QPointer<EffectWindowImpl> >::const_iterator it = wImpl->thumbnails().constBegin();
             it != wImpl->thumbnails().constEnd();
             ++it) {
         if (it.value().isNull()) {
@@ -819,8 +823,6 @@ void Scene::Window::resetPaintingEnabled()
     if (AbstractClient *c = dynamic_cast<AbstractClient*>(toplevel)) {
         if (c->isMinimized())
             disable_painting |= PAINT_DISABLED_BY_MINIMIZE;
-        if (c->tabGroup() && c != c->tabGroup()->current())
-            disable_painting |= PAINT_DISABLED_BY_TAB_GROUP;
         if (c->isHiddenInternal()) {
             disable_painting |= PAINT_DISABLED;
         }
