@@ -71,7 +71,7 @@ namespace KWin
  *      onFinished: console.log(returnValue[0])
  *  }
  * @endcode
- **/
+ */
 class DBusCall : public QObject
 {
     Q_OBJECT
@@ -82,7 +82,7 @@ class DBusCall : public QObject
     Q_PROPERTY(QVariantList arguments READ arguments WRITE setArguments NOTIFY argumentsChanged)
 public:
     explicit DBusCall(QObject* parent = 0);
-    virtual ~DBusCall();
+    ~DBusCall() override;
 
     const QString &service() const;
     const QString &path() const;
