@@ -25,10 +25,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "placement.h"
 #include "screenedge.h"
 #include "screens.h"
+#ifdef KWIN_BUILD_TABBOX
+#include "tabbox.h"
+#endif
+#include "virtualdesktops.h"
 #include "wayland_server.h"
 #include "workspace.h"
-#include "virtualdesktops.h"
-#include "screens.h"
 #include "decorations/decorationbridge.h"
 #include "decorations/decoratedclient.h"
 #include <KDecoration2/Decoration>
@@ -50,15 +52,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KWayland/Server/server_decoration_palette_interface.h>
 #include <KWayland/Server/xdgdecoration_interface.h>
 
-#include <KDesktopFile>
-
 #include <QFileInfo>
-#include <QOpenGLFramebufferObject>
-#include <QWindow>
 
 #include <sys/types.h>
 #include <unistd.h>
-#include <signal.h>
+
+#include <csignal>
 
 Q_DECLARE_METATYPE(NET::WindowType)
 
@@ -76,6 +75,7 @@ ShellClient::ShellClient(ShellSurfaceInterface *surface)
 {
     setSurface(surface->surface());
     init();
+    m_isInitialized = true;
 }
 
 ShellClient::ShellClient(XdgShellSurfaceInterface *surface)
@@ -140,10 +140,11 @@ void ShellClient::initSurface(T *shellSurface)
         resourceName = info.fileName().toUtf8();
     }
     setResourceClass(resourceName, shellSurface->windowClass());
+    setDesktopFileName(shellSurface->windowClass());
     connect(shellSurface, &T::windowClassChanged, this,
         [this, resourceName] (const QByteArray &windowClass) {
             setResourceClass(resourceName, windowClass);
-            if (!m_internal) {
+            if (m_isInitialized && supportsWindowRules()) {
                 setupWindowRules(true);
                 applyWindowRules();
             }
@@ -191,6 +192,12 @@ void ShellClient::initSurface(T *shellSurface)
                 // ignore for wl_shell - there it is mutual exclusive and messes with the geometry
                 return;
             }
+
+            // If the maximized state of the client hasn't been changed due to a window
+            // rule or because the requested state is the same as the current, then the
+            // compositor still has to send a configure event.
+            RequestGeometryBlocker blocker(this);
+
             maximize(maximized ? MaximizeFull : MaximizeRestore);
         }
     );
@@ -201,11 +208,6 @@ void ShellClient::initSurface(T *shellSurface)
 
     connect(this, &ShellClient::geometryChanged, this, &ShellClient::updateClientOutputs);
     connect(screens(), &Screens::changed, this, &ShellClient::updateClientOutputs);
-
-    if (!m_internal) {
-        setupWindowRules(false);
-    }
-    setDesktopFileName(rules()->checkDesktopFile(shellSurface->windowClass(), true).toUtf8());
 }
 
 void ShellClient::init()
@@ -236,7 +238,7 @@ void ShellClient::init()
     connect(s, &SurfaceInterface::sizeChanged, this,
         [this] {
             m_clientSize = surface()->size();
-            doSetGeometry(QRect(geom.topLeft(), m_clientSize + QSize(borderLeft() + borderRight(), borderTop() + borderBottom())));
+            doSetGeometry(QRect(pos(), m_clientSize + QSize(borderLeft() + borderRight(), borderTop() + borderBottom())));
         }
     );
     connect(s, &SurfaceInterface::unmapped, this, &ShellClient::unmap);
@@ -335,17 +337,7 @@ void ShellClient::init()
     }
 
     // set initial desktop
-    setDesktop(rules()->checkDesktop(m_internal ? int(NET::OnAllDesktops) : VirtualDesktopManager::self()->current(), true));
-    // TODO: merge in checks from Client::manage?
-    if (rules()->checkMinimize(false, true)) {
-        minimize(true);   // No animation
-    }
-    setSkipTaskbar(rules()->checkSkipTaskbar(m_plasmaShellSurface ? m_plasmaShellSurface->skipTaskbar() : false, true));
-    setSkipPager(rules()->checkSkipPager(false, true));
-    setSkipSwitcher(rules()->checkSkipSwitcher(false, true));
-    setKeepAbove(rules()->checkKeepAbove(false, true));
-    setKeepBelow(rules()->checkKeepBelow(false, true));
-    setShortcut(rules()->checkShortcut(QString(), true));
+    setDesktop(m_internal ? int(NET::OnAllDesktops) : VirtualDesktopManager::self()->current());
 
     // setup shadow integration
     getShadow();
@@ -359,21 +351,55 @@ void ShellClient::init()
     setTransient();
 
     AbstractClient::updateColorScheme(QString());
-
-    if (!m_internal) {
-        discardTemporaryRules();
-        applyWindowRules(); // Just in case
-        RuleBook::self()->discardUsed(this, false);   // Remove ApplyNow rules
-        updateWindowRules(Rules::All); // Was blocked while !isManaged()
-    }
 }
 
 void ShellClient::finishInit() {
     SurfaceInterface *s = surface();
     disconnect(s, &SurfaceInterface::committed, this, &ShellClient::finishInit);
 
-    if (!isInitialPositionSet()) {
-        QRect area = workspace()->clientArea(PlacementArea, Screens::self()->current(), desktop());
+    bool needsPlacement = !isInitialPositionSet();
+
+    if (supportsWindowRules()) {
+        setupWindowRules(false);
+
+        const QRect originalGeometry = QRect(pos(), sizeForClientSize(clientSize()));
+        const QRect ruledGeometry = rules()->checkGeometry(originalGeometry, true);
+        if (originalGeometry != ruledGeometry) {
+            setGeometry(ruledGeometry);
+        }
+
+        maximize(rules()->checkMaximize(maximizeMode(), true));
+
+        setDesktop(rules()->checkDesktop(desktop(), true));
+        setDesktopFileName(rules()->checkDesktopFile(desktopFileName(), true).toUtf8());
+        if (rules()->checkMinimize(isMinimized(), true)) {
+            minimize(true); // No animation.
+        }
+        setSkipTaskbar(rules()->checkSkipTaskbar(skipTaskbar(), true));
+        setSkipPager(rules()->checkSkipPager(skipPager(), true));
+        setSkipSwitcher(rules()->checkSkipSwitcher(skipSwitcher(), true));
+        setKeepAbove(rules()->checkKeepAbove(keepAbove(), true));
+        setKeepBelow(rules()->checkKeepBelow(keepBelow(), true));
+        setShortcut(rules()->checkShortcut(shortcut().toString(), true));
+        updateColorScheme();
+
+        // Don't place the client if its position is set by a rule.
+        if (rules()->checkPosition(invalidPoint, true) != invalidPoint) {
+            needsPlacement = false;
+        }
+
+        // Don't place the client if the maximize state is set by a rule.
+        if (requestedMaximizeMode() != MaximizeRestore) {
+            needsPlacement = false;
+        }
+
+        discardTemporaryRules();
+        RuleBook::self()->discardUsed(this, false); // Remove Apply Now rules.
+        updateWindowRules(Rules::All);
+    }
+
+    if (needsPlacement) {
+        const QRect area = workspace()->clientArea(PlacementArea, Screens::self()->current(), desktop());
         placeIn(area);
     }
 
@@ -381,41 +407,50 @@ void ShellClient::finishInit() {
     if (m_requestGeometryBlockCounter == 0) {
         requestGeometry(m_blockedRequestGeometry);
     }
+
+    m_isInitialized = true;
 }
 
 void ShellClient::destroyClient()
 {
     m_closing = true;
+#ifdef KWIN_BUILD_TABBOX
+    TabBox::TabBox *tabBox = TabBox::TabBox::self();
+    if (tabBox && tabBox->isDisplayed() && tabBox->currentClient() == this) {
+        tabBox->nextPrev(true);
+    }
+#endif
     if (isMoveResize()) {
         leaveMoveResize();
     }
-    Deleted *del = nullptr;
-    if (workspace()) {
-        del = Deleted::create(this);
-    }
-    emit windowClosed(this, del);
+
+    // Replace ShellClient with an instance of Deleted in the stacking order.
+    Deleted *deleted = Deleted::create(this);
+    emit windowClosed(this, deleted);
+
+    // Remove Force Temporarily rules.
+    RuleBook::self()->discardUsed(this, true);
+
     destroyWindowManagementInterface();
     destroyDecoration();
 
-    if (workspace()) {
-        StackingUpdatesBlocker blocker(workspace());
-        if (transientFor()) {
-            transientFor()->removeTransient(this);
-        }
-        for (auto it = transients().constBegin(); it != transients().constEnd();) {
-            if ((*it)->transientFor() == this) {
-                removeTransient(*it);
-                it = transients().constBegin(); // restart, just in case something more has changed with the list
-            } else {
-                ++it;
-            }
+    StackingUpdatesBlocker blocker(workspace());
+    if (transientFor()) {
+        transientFor()->removeTransient(this);
+    }
+    for (auto it = transients().constBegin(); it != transients().constEnd();) {
+        if ((*it)->transientFor() == this) {
+            removeTransient(*it);
+            it = transients().constBegin(); // restart, just in case something more has changed with the list
+        } else {
+            ++it;
         }
     }
+
     waylandServer()->removeClient(this);
 
-    if (del) {
-        del->unrefWindow();
-    }
+    deleted->unrefWindow();
+
     m_shellSurface = nullptr;
     m_xdgShellSurface = nullptr;
     m_xdgShellPopup = nullptr;
@@ -427,6 +462,16 @@ void ShellClient::deleteClient(ShellClient *c)
     delete c;
 }
 
+QSize ShellClient::toWindowGeometry(const QSize &size) const
+{
+    QSize adjustedSize = size - QSize(borderLeft() + borderRight(), borderTop() + borderBottom());
+    // a client going fullscreen should have the window the contents size of the screen
+    if (!isFullScreen() && requestedMaximizeMode() != MaximizeFull) {
+        adjustedSize -= QSize(m_windowMargins.left() + m_windowMargins.right(), m_windowMargins.top() + m_windowMargins.bottom());
+    }
+    return adjustedSize;
+}
+
 QStringList ShellClient::activities() const
 {
     // TODO: implement
@@ -519,6 +564,7 @@ void ShellClient::addDamage(const QRegion &damage)
     auto s = surface();
     if (s->size().isValid()) {
         m_clientSize = s->size();
+        updateWindowMargins();
         updatePendingGeometry();
     }
     markAsMapped();
@@ -603,10 +649,12 @@ void ShellClient::updateDecoration(bool check_workspace_pos, bool force)
 
 void ShellClient::setGeometry(int x, int y, int w, int h, ForceGeometry_t force)
 {
+    const QRect newGeometry = rules()->checkGeometry(QRect(x, y, w, h));
+
     if (areGeometryUpdatesBlocked()) {
         // when the GeometryUpdateBlocker exits the current geom is passed to setGeometry
         // thus we need to set it here.
-        geom = QRect(x, y, w, h);
+        geom = newGeometry;
         if (pendingGeometryUpdate() == PendingGeometryForced)
             {} // maximum, nothing needed
         else if (force == ForceGeometrySet)
@@ -619,17 +667,17 @@ void ShellClient::setGeometry(int x, int y, int w, int h, ForceGeometry_t force)
         // reset geometry to the one before blocking, so that we can compare properly
         geom = geometryBeforeUpdateBlocking();
     }
-    // TODO: better merge with Client's implementation
-    const QSize requestedClientSize = QSize(w, h) - QSize(borderLeft() + borderRight(), borderTop() + borderBottom());
+    const QSize requestedClientSize = newGeometry.size() - QSize(borderLeft() + borderRight(), borderTop() + borderBottom());
+    const QSize requestedWindowGeometrySize = toWindowGeometry(newGeometry.size());
 
     if (requestedClientSize == m_clientSize && !isWaitingForMoveResizeSync() &&
-        (m_requestedClientSize.isEmpty() || requestedClientSize == m_requestedClientSize)) {
+        (m_requestedClientSize.isEmpty() || requestedWindowGeometrySize == m_requestedClientSize)) {
         // size didn't change, and we don't need to explicitly request a new size
-        doSetGeometry(QRect(x, y, w, h));
+        doSetGeometry(newGeometry);
         updateMaximizeMode(m_requestedMaximizeMode);
     } else {
         // size did change, Client needs to provide a new buffer
-        requestGeometry(QRect(x, y, w, h));
+        requestGeometry(newGeometry);
     }
 }
 
@@ -641,7 +689,9 @@ void ShellClient::doSetGeometry(const QRect &rect)
     if (!m_unmapped) {
         addWorkspaceRepaint(visibleRect());
     }
+
     geom = rect;
+    updateWindowRules(Rules::Position | Rules::Size);
 
     if (m_unmapped && m_geomMaximizeRestore.isEmpty() && !geom.isEmpty()) {
         // use first valid geometry as restore geometry
@@ -736,16 +786,28 @@ bool ShellClient::isFullScreen() const
 
 bool ShellClient::isMaximizable() const
 {
+    if (!isResizable()) {
+        return false;
+    }
+    if (rules()->checkMaximize(MaximizeRestore) != MaximizeRestore || rules()->checkMaximize(MaximizeFull) != MaximizeFull) {
+        return false;
+    }
     return true;
 }
 
 bool ShellClient::isMinimizable() const
 {
+    if (!rules()->checkMinimize(true)) {
+        return false;
+    }
     return (!m_plasmaShellSurface || m_plasmaShellSurface->role() == PlasmaShellSurfaceInterface::Role::Normal);
 }
 
 bool ShellClient::isMovable() const
 {
+    if (rules()->checkPosition(invalidPoint) != invalidPoint) {
+        return false;
+    }
     if (m_plasmaShellSurface) {
         return m_plasmaShellSurface->role() == PlasmaShellSurfaceInterface::Role::Normal;
     }
@@ -757,6 +819,9 @@ bool ShellClient::isMovable() const
 
 bool ShellClient::isMovableAcrossScreens() const
 {
+    if (rules()->checkPosition(invalidPoint) != invalidPoint) {
+        return false;
+    }
     if (m_plasmaShellSurface) {
         return m_plasmaShellSurface->role() == PlasmaShellSurfaceInterface::Role::Normal;
     }
@@ -768,6 +833,9 @@ bool ShellClient::isMovableAcrossScreens() const
 
 bool ShellClient::isResizable() const
 {
+    if (rules()->checkSize(QSize()).isValid()) {
+        return false;
+    }
     if (m_plasmaShellSurface) {
         return m_plasmaShellSurface->role() == PlasmaShellSurfaceInterface::Role::Normal;
     }
@@ -816,8 +884,6 @@ void ShellClient::changeMaximize(bool horizontal, bool vertical, bool adjust)
     const MaximizeMode oldMode = m_requestedMaximizeMode;
     const QRect oldGeometry = geometry();
 
-    StackingUpdatesBlocker blocker(workspace());
-    RequestGeometryBlocker geometryBlocker(this);
     // 'adjust == true' means to update the size only, e.g. after changing workspace size
     if (!adjust) {
         if (vertical)
@@ -825,12 +891,15 @@ void ShellClient::changeMaximize(bool horizontal, bool vertical, bool adjust)
         if (horizontal)
             m_requestedMaximizeMode = MaximizeMode(m_requestedMaximizeMode ^ MaximizeHorizontal);
     }
-    // TODO: add more checks as in Client
 
-    if (m_requestedMaximizeMode == oldMode) {
+    m_requestedMaximizeMode = rules()->checkMaximize(m_requestedMaximizeMode);
+    if (!adjust && m_requestedMaximizeMode == oldMode) {
         return;
     }
 
+    StackingUpdatesBlocker blocker(workspace());
+    RequestGeometryBlocker geometryBlocker(this);
+
     // call into decoration update borders
     if (isDecorated() && decoration()->client() && !(options->borderlessMaximizedWindows() && m_requestedMaximizeMode == KWin::MaximizeFull)) {
         changeMaximizeRecursion = true;
@@ -870,7 +939,6 @@ void ShellClient::changeMaximize(bool horizontal, bool vertical, bool adjust)
         }
     }
 
-    // TODO: check rules
     if (m_requestedMaximizeMode == MaximizeFull) {
         m_geomMaximizeRestore = oldGeometry;
         // TODO: Client has more checks
@@ -923,16 +991,30 @@ bool ShellClient::noBorder() const
     return true;
 }
 
+bool ShellClient::isFullScreenable() const
+{
+    if (!rules()->checkFullScreen(true)) {
+        return false;
+    }
+    return !isSpecialWindow();
+}
+
 void ShellClient::setFullScreen(bool set, bool user)
 {
-    if (!isFullScreen() && !set)
+    set = rules()->checkFullScreen(set);
+
+    const bool wasFullscreen = isFullScreen();
+    if (wasFullscreen == set) {
         return;
-    if (user && !userCanSetFullScreen())
+    }
+    if (isSpecialWindow()) {
         return;
-    set = rules()->checkFullScreen(set && !isSpecialWindow());
-    setShade(ShadeNone);
-    bool was_fs = isFullScreen();
-    if (was_fs) {
+    }
+    if (user && !userCanSetFullScreen()) {
+        return;
+    }
+
+    if (wasFullscreen) {
         workspace()->updateFocusMousePosition(Cursor::pos()); // may cause leave event
     } else {
         // in shell surface, maximise mode and fullscreen are exclusive
@@ -944,18 +1026,18 @@ void ShellClient::setFullScreen(bool set, bool user)
         }
     }
     m_fullScreen = set;
-    if (was_fs == isFullScreen())
-        return;
+
     if (set) {
-        untab();
         workspace()->raiseClient(this);
     }
     RequestGeometryBlocker requestBlocker(this);
     StackingUpdatesBlocker blocker1(workspace());
     GeometryUpdatesBlocker blocker2(this);
+
     workspace()->updateClientLayer(this);   // active fullscreens get different layer
     updateDecoration(false, false);
-    if (isFullScreen()) {
+
+    if (set) {
         setGeometry(workspace()->clientArea(FullScreenArea, this));
     } else {
         if (m_geomFsRestore.isValid()) {
@@ -969,11 +1051,9 @@ void ShellClient::setFullScreen(bool set, bool user)
             setGeometry(QRect(workspace()->clientArea(PlacementArea, this).topLeft(), QSize(0, 0)));
         }
     }
-    updateWindowRules(Rules::Fullscreen|Rules::Position|Rules::Size);
 
-    if (was_fs != isFullScreen()) {
-        emit fullScreenChanged();
-    }
+    updateWindowRules(Rules::Fullscreen|Rules::Position|Rules::Size);
+    emit fullScreenChanged();
 }
 
 void ShellClient::setNoBorder(bool set)
@@ -1030,10 +1110,10 @@ bool ShellClient::userCanSetFullScreen() const
 bool ShellClient::userCanSetNoBorder() const
 {
     if (m_serverDecoration && m_serverDecoration->mode() == ServerSideDecorationManagerInterface::Mode::Server) {
-        return !isFullScreen() && !isShade() && !tabGroup();
+        return !isFullScreen() && !isShade();
     }
     if (m_xdgDecoration && m_xdgDecoration->requestedMode() != XdgDecorationInterface::Mode::ClientSide) {
-        return !isFullScreen() && !isShade() && !tabGroup();
+        return !isFullScreen() && !isShade();
     }
     return false;
 }
@@ -1089,11 +1169,6 @@ pid_t ShellClient::pid() const
     return surface()->client()->processId();
 }
 
-bool ShellClient::isInternal() const
-{
-    return false;
-}
-
 bool ShellClient::isLockScreen() const
 {
     return surface()->client() == waylandServer()->screenLockerClientConnection();
@@ -1113,7 +1188,7 @@ bool ShellClient::requestGeometry(const QRect &rect)
 
     QSize size;
     if (rect.isValid()) {
-        size = rect.size() - QSize(borderLeft() + borderRight(), borderTop() + borderBottom());
+        size = toWindowGeometry(rect.size());
     } else {
         size = QSize(0, 0);
     }
@@ -1132,7 +1207,7 @@ bool ShellClient::requestGeometry(const QRect &rect)
         if (parent) {
             const QPoint globalClientContentPos = parent->geometry().topLeft() + parent->clientPos();
             const QPoint relativeOffset = rect.topLeft() - globalClientContentPos;
-            serialId = m_xdgShellPopup->configure(QRect(relativeOffset, rect.size()));
+            serialId = m_xdgShellPopup->configure(QRect(relativeOffset, size));
         }
     }
 
@@ -1150,7 +1225,7 @@ bool ShellClient::requestGeometry(const QRect &rect)
 
 void ShellClient::updatePendingGeometry()
 {
-    QPoint position = geom.topLeft();
+    QPoint position = pos();
     MaximizeMode maximizeMode = m_maximizeMode;
     for (auto it = m_pendingConfigureRequests.begin(); it != m_pendingConfigureRequests.end(); it++) {
         if (it->serialId > m_lastAckedConfigureRequest) {
@@ -1308,19 +1383,20 @@ void ShellClient::updateShowOnScreenEdge()
     if ((m_plasmaShellSurface->panelBehavior() == PlasmaShellSurfaceInterface::PanelBehavior::AutoHide && m_hidden) ||
         m_plasmaShellSurface->panelBehavior() == PlasmaShellSurfaceInterface::PanelBehavior::WindowsCanCover) {
         // screen edge API requires an edge, thus we need to figure out which edge the window borders
+        const QRect clientGeometry = geometry();
         Qt::Edges edges;
         for (int i = 0; i < screens()->count(); i++) {
-            const auto &screenGeo = screens()->geometry(i);
-            if (screenGeo.x() == geom.x()) {
+            const QRect screenGeometry = screens()->geometry(i);
+            if (screenGeometry.left() == clientGeometry.left()) {
                 edges |= Qt::LeftEdge;
             }
-            if (screenGeo.x() + screenGeo.width() == geom.x() + geom.width()) {
+            if (screenGeometry.right() == clientGeometry.right()) {
                 edges |= Qt::RightEdge;
             }
-            if (screenGeo.y() == geom.y()) {
+            if (screenGeometry.top() == clientGeometry.top()) {
                 edges |= Qt::TopEdge;
             }
-            if (screenGeo.y() + screenGeo.height() == geom.y() + geom.height()) {
+            if (screenGeometry.bottom() == clientGeometry.bottom()) {
                 edges |= Qt::BottomEdge;
             }
         }
@@ -1335,9 +1411,9 @@ void ShellClient::updateShowOnScreenEdge()
         }
         // it's still possible that a panel borders two edges, e.g. bottom and left
         // in that case the one which is sharing more with the edge wins
-        auto check = [this](Qt::Edges edges, Qt::Edge horiz, Qt::Edge vert) {
+        auto check = [clientGeometry](Qt::Edges edges, Qt::Edge horiz, Qt::Edge vert) {
             if (edges.testFlag(horiz) && edges.testFlag(vert)) {
-                if (geom.width() >= geom.height()) {
+                if (clientGeometry.width() >= clientGeometry.height()) {
                     return edges & ~horiz;
                 } else {
                     return edges & ~vert;
@@ -1423,6 +1499,7 @@ void ShellClient::updateMaximizeMode(MaximizeMode maximizeMode)
     }
 
     m_maximizeMode = maximizeMode;
+    updateWindowRules(Rules::MaximizeHoriz | Rules::MaximizeVert | Rules::Position | Rules::Size);
 
     emit clientMaximizedStateChanged(this, m_maximizeMode);
     emit clientMaximizedStateChanged(this, m_maximizeMode & MaximizeHorizontal, m_maximizeMode & MaximizeVertical);
@@ -1807,7 +1884,7 @@ void ShellClient::finishCompositing(ReleaseReason releaseReason)
     Toplevel::finishCompositing(releaseReason);
 }
 
-void ShellClient::placeIn(QRect &area)
+void ShellClient::placeIn(const QRect &area)
 {
     Placement::self()->place(this, area);
     setGeometryRestore(geometry());
@@ -1878,6 +1955,34 @@ void ShellClient::updateClientOutputs()
     surface()->setOutputs(clientOutputs);
 }
 
+void ShellClient::updateWindowMargins()
+{
+    QRect windowGeometry;
+    QSize clientSize = m_clientSize;
+
+    if (m_xdgShellSurface) {
+        windowGeometry = m_xdgShellSurface->windowGeometry();
+    } else if (m_xdgShellPopup) {
+        windowGeometry = m_xdgShellPopup->windowGeometry();
+        if (!clientSize.isValid()) {
+            clientSize = m_xdgShellPopup->initialSize();
+        }
+    } else {
+        return;
+    }
+
+    if (windowGeometry.isEmpty() ||
+        windowGeometry.width() > clientSize.width() ||
+        windowGeometry.height() > clientSize.height()) {
+        m_windowMargins = QMargins();
+    } else {
+        m_windowMargins = QMargins(windowGeometry.left(),
+                                    windowGeometry.top(),
+                                    clientSize.width() - (windowGeometry.right() + 1),
+                                    clientSize.height() - (windowGeometry.bottom() + 1));
+    }
+}
+
 bool ShellClient::isPopupWindow() const
 {
     if (Toplevel::isPopupWindow()) {
@@ -1897,4 +2002,12 @@ QWindow *ShellClient::internalWindow() const
     return nullptr;
 }
 
+bool ShellClient::supportsWindowRules() const
+{
+    if (m_plasmaShellSurface) {
+        return false;
+    }
+    return m_xdgShellSurface;
+}
+
 }
