@@ -42,7 +42,7 @@ namespace KWin
 
 /**
  * @brief The reason for which the server pinged a client surface
- **/
+ */
 enum class PingReason {
     CloseWindow = 0,
     FocusWindow
@@ -55,7 +55,7 @@ public:
     ShellClient(KWayland::Server::ShellSurfaceInterface *surface);
     ShellClient(KWayland::Server::XdgShellSurfaceInterface *surface);
     ShellClient(KWayland::Server::XdgShellPopupInterface *surface);
-    virtual ~ShellClient();
+    ~ShellClient() override;
 
     QStringList activities() const override;
     QPoint clientContentPos() const override;
@@ -77,6 +77,7 @@ public:
     void closeWindow() override;
     AbstractClient *findModal(bool allow_itself = false) override;
     bool isCloseable() const override;
+    bool isFullScreenable() const override;
     bool isFullScreen() const override;
     bool isMaximizable() const override;
     bool isMinimizable() const override;
@@ -119,10 +120,9 @@ public:
      * Note that processes started by kwin will share its process id.
      * @since 5.11
      * @returns the process if for this client.
-     **/
+     */
     pid_t pid() const override;
 
-    virtual bool isInternal() const;
     bool isLockScreen() const override;
     bool isInputMethod() const override;
     virtual QWindow *internalWindow() const;
@@ -148,8 +148,7 @@ public:
 
     void killWindow() override;
 
-    // TODO: const-ref
-    void placeIn(QRect &area);
+    void placeIn(const QRect &area);
 
     bool hasPopupGrab() const override;
     void popupDone() override;
@@ -163,6 +162,8 @@ public:
         return true;
     }
 
+    bool supportsWindowRules() const override;
+
 protected:
     void addDamage(const QRegion &damage) override;
     bool belongsToSameApplication(const AbstractClient *other, SameApplicationChecks checks) const override;
@@ -198,12 +199,12 @@ private Q_SLOTS:
 private:
     /**
      *  Called when the shell is created.
-     **/
+     */
     void init();
     /**
      * Called for the XDG case when the shell surface is committed to the surface.
      * At this point all initial properties should have been set by the client.
-     **/
+     */
     void finishInit();
     template <class T>
     void initSurface(T *shellSurface);
@@ -214,6 +215,7 @@ private:
     void setTransient();
     bool shouldExposeToWindowManagement();
     void updateClientOutputs();
+    void updateWindowMargins();
     KWayland::Server::XdgShellSurfaceInterface::States xdgSurfaceStates() const;
     void updateShowOnScreenEdge();
     void updateMaximizeMode(MaximizeMode maximizeMode);
@@ -222,6 +224,8 @@ private:
     QPoint popupOffset(const QRect &anchorRect, const Qt::Edges anchorEdge, const Qt::Edges gravity, const QSize popupSize) const;
     static void deleteClient(ShellClient *c);
 
+    QSize toWindowGeometry(const QSize &geometry) const;
+
     KWayland::Server::ShellSurfaceInterface *m_shellSurface;
     KWayland::Server::XdgShellSurfaceInterface *m_xdgShellSurface;
     KWayland::Server::XdgShellPopupInterface *m_xdgShellPopup;
@@ -291,7 +295,12 @@ private:
     QString m_captionSuffix;
     QHash<qint32, PingReason> m_pingSerials;
 
+    QMargins m_windowMargins;
+
     bool m_compositingSetup = false;
+    bool m_isInitialized = false;
+
+    friend class Workspace;
 };
 
 }
