@@ -22,9 +22,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "sm.h"
 
 #include <unistd.h>
-#include <stdlib.h>
+#include <cstdlib>
 #include <pwd.h>
-#include <fixx11h.h>
 #include <kconfig.h>
 
 #include "workspace.h"
@@ -125,7 +124,7 @@ void Workspace::commitData(QSessionManager &sm)
  * Stores the current session in the config file
  *
  * @see loadSessionInfo
- **/
+ */
 void Workspace::storeSession(KConfig* config, SMSavePhase phase)
 {
     KConfigGroup cg(config, "Session");
@@ -202,8 +201,6 @@ void Workspace::storeClient(KConfigGroup &cg, int num, Client *c)
     cg.writeEntry(QLatin1String("windowType") + n, windowTypeToTxt(c->windowType()));
     cg.writeEntry(QLatin1String("shortcut") + n, c->shortcut().toString());
     cg.writeEntry(QLatin1String("stackingOrder") + n, unconstrained_stacking_order.indexOf(c));
-    // KConfig doesn't support long so we need to live with less precision on 64-bit systems
-    cg.writeEntry(QLatin1String("tabGroup") + n, static_cast<int>(reinterpret_cast<long>(c->tabGroup())));
     cg.writeEntry(QLatin1String("activities") + n, c->activities());
 }
 
@@ -243,7 +240,7 @@ void Workspace::storeSubSession(const QString &name, QSet<QByteArray> sessionIds
  * Loads the session information from the config file.
  *
  * @see storeSession
- **/
+ */
 void Workspace::loadSessionInfo(const QString &key)
 {
     // NOTICE: qApp->sessionKey() is outdated when this gets invoked
@@ -287,8 +284,6 @@ void Workspace::addSessionInfo(KConfigGroup &cg)
         info->shortcut = cg.readEntry(QLatin1String("shortcut") + n, QString());
         info->active = (active_client == i);
         info->stackingOrder = cg.readEntry(QLatin1String("stackingOrder") + n, -1);
-        info->tabGroup = cg.readEntry(QLatin1String("tabGroup") + n, 0);
-        info->tabGroupClient = NULL;
         info->activities = cg.readEntry(QLatin1String("activities") + n, QStringList());
     }
 }
@@ -316,7 +311,7 @@ static bool sessionInfoWindowTypeMatch(Client* c, SessionInfo* info)
  * We try to find a matching entry in the session.
  *
  * May return 0 if there's no session info for the client.
- **/
+ */
 SessionInfo* Workspace::takeSessionInfo(Client* c)
 {
     SessionInfo *realInfo = 0;
@@ -363,15 +358,6 @@ SessionInfo* Workspace::takeSessionInfo(Client* c)
             }
         }
     }
-
-    // Set tabGroupClient for other clients in the same group
-    if (realInfo && realInfo->tabGroup) {
-        foreach (SessionInfo * info, session) {
-            if (!info->tabGroupClient && info->tabGroup == realInfo->tabGroup)
-                info->tabGroupClient = c;
-        }
-    }
-
     return realInfo;
 }
 
