@@ -920,7 +920,7 @@ struct KeySymbolsDeleter
 
 /**
  * Handles alt-tab / control-tab
- **/
+ */
 static bool areKeySymXsDepressed(const uint keySyms[], int nKeySyms)
 {
     Xcb::QueryKeymap keys;
@@ -1470,7 +1470,7 @@ int TabBox::previousDesktopStatic(int iDesktop) const
 /**
  * Auxiliary functions to travers all clients according to the static
  * order. Useful for the CDE-style Alt-tab feature.
- **/
+ */
 AbstractClient* TabBox::nextClientStatic(AbstractClient* c) const
 {
     const auto &list = Workspace::self()->allClientList();
@@ -1488,7 +1488,7 @@ AbstractClient* TabBox::nextClientStatic(AbstractClient* c) const
 /**
  * Auxiliary functions to travers all clients according to the static
  * order. Useful for the CDE-style Alt-tab feature.
- **/
+ */
 AbstractClient* TabBox::previousClientStatic(AbstractClient* c) const
 {
     const auto &list = Workspace::self()->allClientList();
@@ -1517,7 +1517,7 @@ bool TabBox::establishTabBoxGrab()
     // in order to catch MouseRelease events and close the tabbox (#67416).
     // All clients already have passive grabs in their wrapper windows, so check only
     // the active client, which may not have it.
-    assert(!m_forcedGlobalMouseGrab);
+    Q_ASSERT(!m_forcedGlobalMouseGrab);
     m_forcedGlobalMouseGrab = true;
     if (Workspace::self()->activeClient() != nullptr)
         Workspace::self()->activeClient()->updateMouseGrab();
@@ -1533,7 +1533,7 @@ void TabBox::removeTabBoxGrab()
     }
     updateXTime();
     ungrabXKeyboard();
-    assert(m_forcedGlobalMouseGrab);
+    Q_ASSERT(m_forcedGlobalMouseGrab);
     m_forcedGlobalMouseGrab = false;
     if (Workspace::self()->activeClient() != nullptr)
         Workspace::self()->activeClient()->updateMouseGrab();
