@@ -36,12 +36,10 @@ namespace KWin
 
 AbstractThumbnailItem::AbstractThumbnailItem(QQuickItem *parent)
     : QQuickPaintedItem(parent)
-    , m_parent(QWeakPointer<EffectWindowImpl>())
     , m_brightness(1.0)
     , m_saturation(1.0)
     , m_clipToItem()
 {
-    Q_ASSERT(Compositor::isCreated());
     connect(Compositor::self(), SIGNAL(compositingToggled(bool)), SLOT(compositingToggled()));
     compositingToggled();
     QTimer::singleShot(0, this, SLOT(init()));
@@ -64,8 +62,8 @@ void AbstractThumbnailItem::compositingToggled()
 void AbstractThumbnailItem::init()
 {
     findParentEffectWindow();
-    if (!m_parent.isNull()) {
-        m_parent.data()->registerThumbnail(this);
+    if (m_parent) {
+        m_parent->registerThumbnail(this);
     }
 }
 
@@ -78,7 +76,7 @@ void AbstractThumbnailItem::findParentEffectWindow()
             return;
         }
         if (auto *w = static_cast<EffectWindowImpl*>(effects->findWindow(qw))) {
-            m_parent = QWeakPointer<EffectWindowImpl>(w);
+            m_parent = QPointer<EffectWindowImpl>(w);
         }
     }
 }
@@ -89,8 +87,8 @@ void AbstractThumbnailItem::effectWindowAdded()
     // by using this slot we can register the thumbnail when it is finally created
     if (m_parent.isNull()) {
         findParentEffectWindow();
-        if (!m_parent.isNull()) {
-            m_parent.data()->registerThumbnail(this);
+        if (m_parent) {
+            m_parent->registerThumbnail(this);
         }
     }
 }
