@@ -31,19 +31,15 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kkeyserver.h>
 
 #ifndef KCMRULES
-#include <assert.h>
 #include <QApplication>
 #include <QDebug>
 
-#include <X11/Xlib.h>
-
-#include <stdio.h>
-
 #include "atoms.h"
 #include "platform.h"
 #include "workspace.h"
 
-#include <signal.h>
+#include <csignal>
+#include <cstdio>
 
 #endif
 
@@ -70,6 +66,15 @@ StrutRect::StrutRect(const StrutRect& other)
 {
 }
 
+StrutRect &StrutRect::operator=(const StrutRect &other)
+{
+    if (this != &other) {
+        QRect::operator=(other);
+        m_area = other.area();
+    }
+    return *this;
+}
+
 #endif
 
 #ifndef KCMRULES
@@ -88,7 +93,7 @@ void grabXServer()
 
 void ungrabXServer()
 {
-    assert(server_grab_count > 0);
+    Q_ASSERT(server_grab_count > 0);
     if (--server_grab_count == 0) {
         xcb_ungrab_server(connection());
         xcb_flush(connection());
