@@ -21,6 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define KWIN_WAYLAND_SERVER_H
 
 #include <kwinglobals.h>
+#include "keyboard_input.h"
 
 #include <QObject>
 
@@ -66,6 +67,7 @@ class XdgDecorationManagerInterface;
 class XdgShellInterface;
 class XdgForeignInterface;
 class XdgOutputManagerInterface;
+class KeyStateInterface;
 }
 }
 
@@ -89,7 +91,7 @@ public:
 
     Q_DECLARE_FLAGS(InitalizationFlags, InitalizationFlag)
 
-    virtual ~WaylandServer();
+    ~WaylandServer() override;
     bool init(const QByteArray &socketName = QByteArray(), InitalizationFlags flags = InitalizationFlag::NoOptions);
     void terminateClientConnections();
 
@@ -135,33 +137,33 @@ public:
 
     /**
      * @returns a transient parent of a surface imported with the foreign protocol, if any
-     **/
+     */
     KWayland::Server::SurfaceInterface *findForeignTransientForSurface(KWayland::Server::SurfaceInterface *surface);
 
     /**
      * @returns file descriptor for Xwayland to connect to.
-     **/
+     */
     int createXWaylandConnection();
     void destroyXWaylandConnection();
 
     /**
      * @returns file descriptor to the input method server's socket.
-     **/
+     */
     int createInputMethodConnection();
     void destroyInputMethodConnection();
 
     /**
      * @returns true if screen is locked.
-     **/
+     */
     bool isScreenLocked() const;
     /**
      * @returns whether integration with KScreenLocker is available.
-     **/
+     */
     bool hasScreenLockerIntegration() const;
 
     /**
      * @returns whether any kind of global shortcuts are supported.
-     **/
+     */
     bool hasGlobalShortcutSupport() const;
 
     void createInternalConnection();
@@ -203,23 +205,24 @@ public:
     /**
      * Struct containing information for a created Wayland connection through a
      * socketpair.
-     **/
+     */
     struct SocketPairConnection {
         /**
          * ServerSide Connection
-         **/
+         */
         KWayland::Server::ClientConnection *connection = nullptr;
         /**
          * client-side file descriptor for the socket
-         **/
+         */
         int fd = -1;
     };
     /**
      * Creates a Wayland connection using a socket pair.
-     **/
+     */
     SocketPairConnection createConnection();
 
     void simulateUserActivity();
+    void updateKeyState(KWin::Xkb::LEDs leds);
 
 Q_SIGNALS:
     void shellClientAdded(KWin::ShellClient*);
@@ -230,11 +233,8 @@ Q_SIGNALS:
 
 private:
     void shellClientShown(Toplevel *t);
-    void initOutputs();
-    void syncOutputsToWayland();
     quint16 createClientId(KWayland::Server::ClientConnection *c);
     void destroyInternalConnection();
-    void configurationChangeRequested(KWayland::Server::OutputConfigurationInterface *config);
     template <class T>
     void createSurface(T *surface);
     void initScreenLocker();
@@ -275,6 +275,7 @@ private:
 
     } m_internalConnection;
     KWayland::Server::XdgForeignInterface *m_XdgForeign = nullptr;
+    KWayland::Server::KeyStateInterface *m_keyState = nullptr;
     QList<ShellClient*> m_clients;
     QList<ShellClient*> m_internalClients;
     QHash<KWayland::Server::ClientConnection*, quint16> m_clientIds;
