@@ -176,7 +176,8 @@ Workspace::Workspace(const QString &sessionKey)
     if (Compositor::self()) {
         m_compositor = Compositor::self();
     } else {
-        m_compositor = Compositor::create(this);
+        Q_ASSERT(kwinApp()->operationMode() == Application::OperationMode::OperationModeX11);
+        m_compositor = X11Compositor::create(this);
     }
     connect(this, &Workspace::currentDesktopChanged, m_compositor, &Compositor::addRepaintFull);
     connect(m_compositor, &QObject::destroyed, this, [this] { m_compositor = nullptr; });
@@ -293,7 +294,7 @@ void Workspace::init()
                 c->updateDecoration(false);
                 updateClientLayer(c);
                 if (!c->isInternal()) {
-                    QRect area = clientArea(PlacementArea, Screens::self()->current(), c->desktop());
+                    const QRect area = clientArea(PlacementArea, Screens::self()->current(), c->desktop());
                     bool placementDone = false;
                     if (c->isInitialPositionSet()) {
                         placementDone = true;
@@ -301,6 +302,12 @@ void Workspace::init()
                     if (c->isFullScreen()) {
                         placementDone = true;
                     }
+                    if (c->maximizeMode() == MaximizeMode::MaximizeFull) {
+                        placementDone = true;
+                    }
+                    if (c->rules()->checkPosition(invalidPoint, true) != invalidPoint) {
+                        placementDone = true;
+                    }
                     if (!placementDone) {
                         c->placeIn(area);
                     }
@@ -316,12 +323,13 @@ void Workspace::init()
                 if (c->wantsInput() && !c->isMinimized()) {
                     activateClient(c);
                 }
+                updateTabbox();
                 connect(c, &ShellClient::windowShown, this,
                     [this, c] {
                         updateClientLayer(c);
                         // TODO: when else should we send the client through placement?
                         if (c->hasTransientPlacementHint()) {
-                            QRect area = clientArea(PlacementArea, Screens::self()->current(), c->desktop());
+                            const QRect area = clientArea(PlacementArea, Screens::self()->current(), c->desktop());
                             c->placeIn(area);
                         }
                         markXStackingOrderAsDirty();
@@ -334,6 +342,7 @@ void Workspace::init()
                 );
                 connect(c, &ShellClient::windowHidden, this,
                     [this] {
+                        // TODO: update tabbox if it's displayed
                         markXStackingOrderAsDirty();
                         updateStackingOrder(true);
                         updateClientArea();
@@ -364,6 +373,7 @@ void Workspace::init()
                 markXStackingOrderAsDirty();
                 updateStackingOrder(true);
                 updateClientArea();
+                updateTabbox();
             }
         );
     }
@@ -546,6 +556,19 @@ Workspace::~Workspace()
         desktops.removeAll(c);
     }
     Client::cleanupX11();
+
+    if (waylandServer()) {
+        const QList<ShellClient *> shellClients = waylandServer()->clients();
+        for (ShellClient *shellClient : shellClients) {
+            shellClient->destroyClient();
+        }
+
+        const QList<ShellClient *> internalClients = waylandServer()->internalClients();
+        for (ShellClient *internalClient : internalClients) {
+            internalClient->destroyClient();
+        }
+    }
+
     for (UnmanagedList::iterator it = unmanaged.begin(), end = unmanaged.end(); it != end; ++it)
         (*it)->release(ReleaseReason::KWinShutsDown);
 
@@ -586,7 +609,9 @@ Client* Workspace::createClient(xcb_window_t w, bool is_mapped)
     StackingUpdatesBlocker blocker(this);
     Client* c = new Client();
     setupClientConnections(c);
-    connect(c, SIGNAL(blockingCompositingChanged(KWin::Client*)), m_compositor, SLOT(updateCompositeBlocking(KWin::Client*)));
+    if (X11Compositor *compositor = X11Compositor::self()) {
+        connect(c, &Client::blockingCompositingChanged, compositor, &X11Compositor::updateClientCompositeBlocking);
+    }
     connect(c, SIGNAL(clientFullScreenSet(KWin::Client*,bool,bool)), ScreenEdges::self(), SIGNAL(checkBlocking()));
     if (!c->manage(w, is_mapped)) {
         Client::deleteClient(c);
@@ -598,14 +623,17 @@ Client* Workspace::createClient(xcb_window_t w, bool is_mapped)
 
 Unmanaged* Workspace::createUnmanaged(xcb_window_t w)
 {
-    if (m_compositor && m_compositor->checkForOverlayWindow(w))
-        return NULL;
+    if (X11Compositor *compositor = X11Compositor::self()) {
+        if (compositor->checkForOverlayWindow(w)) {
+            return nullptr;
+        }
+    }
     Unmanaged* c = new Unmanaged();
     if (!c->track(w)) {
         Unmanaged::deleteUnmanaged(c);
         return NULL;
     }
-    connect(c, SIGNAL(needsRepaint()), m_compositor, SLOT(scheduleRepaint()));
+    connect(c, &Unmanaged::needsRepaint, m_compositor, &Compositor::scheduleRepaint);
     addUnmanaged(c);
     emit unmanagedAdded(c);
     return c;
@@ -647,10 +675,7 @@ void Workspace::addClient(Client* c)
     updateStackingOrder(true);   // Propagate new client
     if (c->isUtility() || c->isMenu() || c->isToolbar())
         updateToolWindows(true);
-#ifdef KWIN_BUILD_TABBOX
-    if (TabBox::TabBox::self()->isDisplayed())
-        TabBox::TabBox::self()->reset(true);
-#endif
+    updateTabbox();
 }
 
 void Workspace::addUnmanaged(Unmanaged* c)
@@ -661,7 +686,7 @@ void Workspace::addUnmanaged(Unmanaged* c)
 
 /**
  * Destroys the client \a c
- **/
+ */
 void Workspace::removeClient(Client* c)
 {
     if (c == active_popup_client)
@@ -670,8 +695,6 @@ void Workspace::removeClient(Client* c)
         m_userActionsMenu->close();
     }
 
-    c->untab(QRect(), true);
-
     if (client_keys_client == c)
         setupWindowShortcutDone(false);
     if (!c->shortcut().isEmpty()) {
@@ -702,19 +725,13 @@ void Workspace::removeClient(Client* c)
     emit clientRemoved(c);
 
     updateStackingOrder(true);
-
-#ifdef KWIN_BUILD_TABBOX
-    TabBox::TabBox *tabBox = TabBox::TabBox::self();
-    if (tabBox->isDisplayed())
-        tabBox->reset(true);
-#endif
-
     updateClientArea();
+    updateTabbox();
 }
 
 void Workspace::removeUnmanaged(Unmanaged* c)
 {
-    assert(unmanaged.contains(c));
+    Q_ASSERT(unmanaged.contains(c));
     unmanaged.removeAll(c);
     emit unmanagedRemoved(c);
     markXStackingOrderAsDirty();
@@ -722,7 +739,7 @@ void Workspace::removeUnmanaged(Unmanaged* c)
 
 void Workspace::addDeleted(Deleted* c, Toplevel *orig)
 {
-    assert(!deleted.contains(c));
+    Q_ASSERT(!deleted.contains(c));
     deleted.append(c);
     const int unconstraintedIndex = unconstrained_stacking_order.indexOf(orig);
     if (unconstraintedIndex != -1) {
@@ -737,19 +754,22 @@ void Workspace::addDeleted(Deleted* c, Toplevel *orig)
         stacking_order.append(c);
     }
     markXStackingOrderAsDirty();
-    connect(c, SIGNAL(needsRepaint()), m_compositor, SLOT(scheduleRepaint()));
+    connect(c, &Deleted::needsRepaint, m_compositor, &Compositor::scheduleRepaint);
 }
 
 void Workspace::removeDeleted(Deleted* c)
 {
-    assert(deleted.contains(c));
+    Q_ASSERT(deleted.contains(c));
     emit deletedRemoved(c);
     deleted.removeAll(c);
     unconstrained_stacking_order.removeAll(c);
     stacking_order.removeAll(c);
     markXStackingOrderAsDirty();
-    if (c->wasClient() && m_compositor) {
-        m_compositor->updateCompositeBlocking();
+    if (!c->wasClient()) {
+        return;
+    }
+    if (X11Compositor *compositor = X11Compositor::self()) {
+        compositor->updateClientCompositeBlocking();
     }
 }
 
@@ -758,8 +778,7 @@ void Workspace::updateToolWindows(bool also_hide)
     // TODO: What if Client's transiency/group changes? should this be called too? (I'm paranoid, am I not?)
     if (!options->isHideUtilityWindowsForInactive()) {
         for (ClientList::ConstIterator it = clients.constBegin(); it != clients.constEnd(); ++it)
-            if (!(*it)->tabGroup() || (*it)->tabGroup()->current() == *it)
-                (*it)->hideClient(false);
+            (*it)->hideClient(false);
         return;
     }
     const Group* group = nullptr;
@@ -862,7 +881,7 @@ void Workspace::reconfigure()
 
 /**
  * Reread settings
- **/
+ */
 
 void Workspace::slotReconfigure()
 {
@@ -1009,7 +1028,7 @@ AbstractClient *Workspace::findClientToActivateOnDesktop(uint desktop)
  * do *not* call this directly; it does not set the activity.
  *
  * Shows/Hides windows according to the stacking order
- **/
+ */
 
 void Workspace::updateCurrentActivity(const QString &new_activity)
 {
@@ -1143,7 +1162,7 @@ void Workspace::selectWmInputEventMask()
  * Sends client \a c to desktop \a desk.
  *
  * Takes care of transients as well.
- **/
+ */
 void Workspace::sendClientToDesktop(AbstractClient* c, int desk, bool dont_activate)
 {
     if ((desk < 1 && desk != NET::OnAllDesktops) || desk > static_cast<int>(VirtualDesktopManager::self()->count()))
@@ -1182,7 +1201,7 @@ void Workspace::sendClientToDesktop(AbstractClient* c, int desk, bool dont_activ
  *
  * this is NOT in any way related to XRandR multiscreen
  *
- **/
+ */
 extern bool is_multihead; // main.cpp
 bool Workspace::isOnCurrentHead()
 {
@@ -1217,7 +1236,7 @@ void Workspace::sendPingToWindow(xcb_window_t window, xcb_timestamp_t timestamp)
 
 /**
  * Delayed focus functions
- **/
+ */
 void Workspace::delayFocus()
 {
     requestFocus(delayfocus_client);
@@ -1248,7 +1267,7 @@ bool Workspace::checkStartupNotification(xcb_window_t w, KStartupInfoId &id, KSt
 /**
  * Puts the focus on a dummy window
  * Just using XSetInputFocus() with None would block keyboard input
- **/
+ */
 void Workspace::focusToNull()
 {
     if (m_nullFocus) {
@@ -1748,6 +1767,11 @@ Toplevel *Workspace::findInternal(QWindow *w) const
     }
 }
 
+bool Workspace::compositing() const
+{
+    return m_compositor && m_compositor->scene();
+}
+
 void Workspace::markXStackingOrderAsDirty()
 {
     m_xStackingDirty = true;
@@ -1770,5 +1794,15 @@ void Workspace::setWasUserInteraction()
     );
 }
 
+void Workspace::updateTabbox()
+{
+#ifdef KWIN_BUILD_TABBOX
+    TabBox::TabBox *tabBox = TabBox::TabBox::self();
+    if (tabBox && tabBox->isDisplayed()) {
+        tabBox->reset(true);
+    }
+#endif
+}
+
 } // namespace
 
