@@ -24,8 +24,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define KWIN_WORKSPACE_H
 
 // kwin
-#include "sm.h"
 #include "options.h"
+#include "sm.h"
 #include "utils.h"
 // Qt
 #include <QTimer>
@@ -34,14 +34,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <functional>
 #include <memory>
 
-// TODO: Cleanup the order of things in this .h file
-
-class QStringList;
 class KConfig;
 class KConfigGroup;
 class KStartupInfo;
-class KStartupInfoId;
 class KStartupInfoData;
+class KStartupInfoId;
+class QStringList;
 
 namespace KWin
 {
@@ -54,10 +52,10 @@ class Window;
 
 class AbstractClient;
 class Client;
+class Compositor;
 class KillWindow;
 class ShortcutDialog;
 class UserActionsMenu;
-class Compositor;
 class X11EventFilter;
 enum class Predicate;
 
@@ -66,7 +64,7 @@ class KWIN_EXPORT Workspace : public QObject
     Q_OBJECT
 public:
     explicit Workspace(const QString &sessionKey = QString());
-    virtual ~Workspace();
+    ~Workspace() override;
 
     static Workspace* self() {
         return _self;
@@ -105,7 +103,7 @@ public:
      * This can either be a function pointer or a function object.
      * @return KWin::Client* The found Client or @c null
      * @see findClient(Predicate, xcb_window_t)
-     **/
+     */
     Client *findClient(std::function<bool (const Client*)> func) const;
     AbstractClient *findAbstractClient(std::function<bool (const AbstractClient*)> func) const;
     /**
@@ -115,7 +113,7 @@ public:
      * @param w The window id to test against
      * @return KWin::Client* The found Client or @c null
      * @see findClient(std::function<bool (const Client*)>)
-     **/
+     */
     Client *findClient(Predicate predicate, xcb_window_t w) const;
     void forEachClient(std::function<void (Client*)> func);
     void forEachAbstractClient(std::function<void (AbstractClient*)> func);
@@ -125,14 +123,14 @@ public:
      *
      * @param w The window id to search for
      * @return KWin::Unmanaged* Found Unmanaged or @c null if there is no Unmanaged with given Id.
-     **/
+     */
     Unmanaged *findUnmanaged(xcb_window_t w) const;
     void forEachUnmanaged(std::function<void (Unmanaged*)> func);
     Toplevel *findToplevel(std::function<bool (const Toplevel*)> func) const;
     /**
      * Finds the Toplevel for the KWin internal window @p w.
      * On Wayland this is normally a ShellClient. For X11 an Unmanaged.
-     **/
+     */
     Toplevel *findToplevel(QWindow *w) const;
     /**
      * @brief Finds a Toplevel for the internal window @p w.
@@ -141,7 +139,7 @@ public:
      * and mapped by the window id, on Wayland a ShellClient mapped on the internal window id.
      *
      * @returns Toplevel
-     **/
+     */
     Toplevel *findInternal(QWindow *w) const;
 
     QRect clientArea(clientAreaOption, const QPoint& p, int desktop) const;
@@ -155,13 +153,13 @@ public:
     /**
      * Returns the active client, i.e. the client that has the focus (or None
      * if no client has the focus)
-     **/
+     */
     AbstractClient* activeClient() const;
     /**
      * Client that was activated, but it's not yet really activeClient(), because
      * we didn't process yet the matching FocusIn event. Used mostly in focus
      * stealing prevention code.
-     **/
+     */
     AbstractClient* mostRecentlyActivatedClient() const;
 
     AbstractClient* clientUnderMouse(int screen) const;
@@ -187,7 +185,7 @@ public:
 
     /**
      * Indicates that the client c is being moved or resized by the user.
-     **/
+     */
     void setMoveResizeClient(AbstractClient* c);
 
     QPoint adjustClientPosition(AbstractClient* c, QPoint pos, bool unrestricted, double snapAdjust = 1.0);
@@ -211,31 +209,31 @@ public:
 
     /**
      * @return List of clients currently managed by Workspace
-     **/
+     */
     const ClientList &clientList() const {
         return clients;
     }
     /**
      * @return List of unmanaged "clients" currently registered in Workspace
-     **/
+     */
     const UnmanagedList &unmanagedList() const {
         return unmanaged;
     }
     /**
      * @return List of desktop "clients" currently managed by Workspace
-     **/
+     */
     const ClientList &desktopList() const {
         return desktops;
     }
     /**
      * @return List of deleted "clients" currently managed by Workspace
-     **/
+     */
     const DeletedList &deletedList() const {
         return deleted;
     }
     /**
      * @returns List of all clients (either X11 or Wayland) currently managed by Workspace
-     **/
+     */
     const QList<AbstractClient*> allClientList() const {
         return m_allClients;
     }
@@ -264,7 +262,7 @@ public:
     /**
      * Returns the list of clients sorted in stacking order, with topmost client
      * at the last position
-     **/
+     */
     const ToplevelList& stackingOrder() const;
     ToplevelList xStackingOrder() const;
     ClientList ensureStackingOrder(const ClientList& clients) const;
@@ -288,7 +286,7 @@ public:
     /**
      * Shows the menu operations menu for the client and makes it active if
      * it's not already.
-     **/
+     */
     void showWindowMenu(const QRect& pos, AbstractClient* cl);
     const UserActionsMenu *userActionsMenu() const {
         return m_userActionsMenu;
@@ -357,7 +355,7 @@ public:
      * is esp. called on enter/motion events of inactive windows
      * since an active window doesn't receive mouse events, it must also be invoked if a (potentially)
      * active window might be moved/resize away from the cursor (causing a leave event)
-     **/
+     */
     void updateFocusMousePosition(const QPoint& pos);
     QPoint focusMousePosition() const;
 
@@ -365,14 +363,14 @@ public:
      * Returns a client that is currently being moved or resized by the user.
      *
      * If none of clients is being moved or resized, @c null will be returned.
-     **/
+     */
     AbstractClient* moveResizeClient() {
         return movingClient;
     }
 
     /**
      * @returns Whether we have a Compositor and it is active (Scene created)
-     **/
+     */
     bool compositing() const;
 
     void registerEventFilter(X11EventFilter *filter);
@@ -457,10 +455,6 @@ public Q_SLOTS:
 
     void updateClientArea();
 
-    void slotActivateNextTab(); // Slot to move left the active Client.
-    void slotActivatePrevTab(); // Slot to move right the active Client.
-    void slotUntab(); // Slot to remove the active client from its group.
-
 private Q_SLOTS:
     void desktopResized();
     void selectWmInputEventMask();
@@ -480,7 +474,7 @@ Q_SIGNALS:
     /**
      * Emitted after the Workspace has setup the complete initialization process.
      * This can be used to connect to for performing post-workspace initialization.
-     **/
+     */
     void workspaceInitialized();
 
     //Signals required for the scripting interface
@@ -496,12 +490,11 @@ Q_SIGNALS:
     void unmanagedRemoved(KWin::Unmanaged*);
     void deletedRemoved(KWin::Deleted*);
     void configChanged();
-    void reinitializeCompositing();
     void showingDesktopChanged(bool showing);
     /**
      * This signels is emitted when ever the stacking order is change, ie. a window is risen
      * or lowered
-     **/
+     */
     void stackingOrderChanged();
 
 private:
@@ -554,6 +547,7 @@ private:
     QList<SessionInfo*> session;
 
     void updateXStackingOrder();
+    void updateTabbox();
 
     AbstractClient* active_client;
     AbstractClient* last_active_client;
@@ -596,7 +590,7 @@ private:
     /**
      * Holds the menu containing the user actions which is shown
      * on e.g. right click the window decoration.
-     **/
+     */
     UserActionsMenu *m_userActionsMenu;
 
     void modalActionsSwitch(bool enabled);
@@ -644,7 +638,7 @@ private:
 
 /**
  * Helper for Workspace::blockStackingUpdates() being called in pairs (True/false)
- **/
+ */
 class StackingUpdatesBlocker
 {
 public:
@@ -665,7 +659,7 @@ class ColorMapper : public QObject
     Q_OBJECT
 public:
     ColorMapper(QObject *parent);
-    virtual ~ColorMapper();
+    ~ColorMapper() override;
 public Q_SLOTS:
     void update();
 private:
